@@ -1,8 +1,9 @@
 """Module for Gens API."""
 
 import logging
-from typing import Dict, List
 
+from cg.constants.constants import PrepCategory
+from cg.store.models import Case
 from cg.utils import Process
 from cg.utils.dict import get_list_from_dictionary
 
@@ -12,7 +13,7 @@ LOG = logging.getLogger(__name__)
 class GensAPI:
     """API for Gens."""
 
-    def __init__(self, config: Dict[str, Dict[str, str]]):
+    def __init__(self, config: dict[str, dict[str, str]]):
         self.binary_path: str = config["gens"]["binary_path"]
         self.config_path: str = config["gens"]["config_path"]
         self.process: Process = Process(
@@ -33,15 +34,25 @@ class GensAPI:
         sample_id: str,
     ) -> None:
         """Load Gens sample file paths into database."""
-        load_params: Dict[str, str] = {
+        load_params: dict[str, str] = {
             "--sample-id": sample_id,
             "--genome-build": genome_build,
             "--baf": baf_path,
             "--coverage": coverage_path,
             "--case-id": case_id,
         }
-        load_call_params: List[str] = ["load", "sample"] + get_list_from_dictionary(load_params)
+        load_call_params: list[str] = ["load", "sample", "--force"]
+        load_call_params += get_list_from_dictionary(load_params)
         self.process.run_command(parameters=load_call_params, dry_run=self.dry_run)
+        if self.process.stderr:
+            LOG.warning(self.process.stderr)
+
+    @staticmethod
+    def is_suitable_for_upload(case: Case) -> bool:
+        """Check if a cancer case supports Gens upload."""
+        return all(
+            sample.prep_category == PrepCategory.WHOLE_GENOME_SEQUENCING for sample in case.samples
+        )
 
     def __str__(self):
         return f"GensAPI(dry_run: {self.dry_run})"
