@@ -3,10 +3,9 @@
 import logging
 from pathlib import Path
 from subprocess import CalledProcessError
-from typing import Optional, Dict
 
 from cg.constants.constants import FileFormat
-from cg.exc import LoqusdbDeleteCaseError, CaseNotFoundError
+from cg.exc import CaseNotFoundError, LoqusdbDeleteCaseError
 from cg.io.controller import ReadStream
 from cg.utils import Process
 from cg.utils.dict import get_list_from_dictionary
@@ -26,14 +25,15 @@ class LoqusdbAPI:
         self,
         case_id: str,
         snv_vcf_path: Path,
-        sv_vcf_path: Optional[Path] = None,
-        profile_vcf_path: Optional[Path] = None,
-        family_ped_path: Optional[Path] = None,
-        window_size: Optional[int] = None,
-        gq_threshold: Optional[int] = None,
-        hard_threshold: Optional[float] = None,
-        soft_threshold: Optional[float] = None,
-    ) -> Dict[str, int]:
+        sv_vcf_path: Path | None = None,
+        profile_vcf_path: Path | None = None,
+        family_ped_path: Path | None = None,
+        window_size: int | None = None,
+        gq_threshold: int | None = None,
+        qual_gq: bool | None = False,
+        hard_threshold: float | None = None,
+        soft_threshold: float | None = None,
+    ) -> dict[str, int]:
         """Add observations to Loqusdb from VCF files."""
         load_params = {
             "--case-id": case_id,
@@ -46,11 +46,12 @@ class LoqusdbAPI:
             "--hard-threshold": str(hard_threshold) if hard_threshold else None,
             "--soft-threshold": str(soft_threshold) if soft_threshold else None,
         }
-        load_call_params: list = ["load"] + get_list_from_dictionary(load_params)
+        load_call_params: list[str] = ["load"] + get_list_from_dictionary(load_params)
+        load_call_params.append("--qual-gq") if qual_gq else None
         self.process.run_command(parameters=load_call_params)
         return self.get_nr_of_variants_in_file()
 
-    def get_case(self, case_id: str) -> Optional[dict]:
+    def get_case(self, case_id: str) -> dict | None:
         """Return a case found in Loqusdb."""
         cases_parameters = ["cases", "-c", case_id, "--to-json"]
         self.process.run_command(parameters=cases_parameters)
@@ -62,7 +63,7 @@ class LoqusdbAPI:
             file_format=FileFormat.JSON, stream=self.process.stdout
         )[0]
 
-    def get_duplicate(self, profile_vcf_path: Path, profile_threshold: float) -> Optional[dict]:
+    def get_duplicate(self, profile_vcf_path: Path, profile_threshold: float) -> dict | None:
         """Find matching profiles in Loqusdb."""
         duplicates_params = {
             "--check-vcf": profile_vcf_path.as_posix(),
@@ -98,7 +99,7 @@ class LoqusdbAPI:
         LOG.error(f"Could not delete case {case_id} from {repr(self)}")
         raise LoqusdbDeleteCaseError
 
-    def get_nr_of_variants_in_file(self) -> Dict[str, int]:
+    def get_nr_of_variants_in_file(self) -> dict[str, int]:
         """Return the number of variants in the uploaded to Loqusdb file."""
         nr_of_variants: int = 0
         for line in self.process.stderr_lines():
@@ -108,4 +109,4 @@ class LoqusdbAPI:
         return {"variants": nr_of_variants}
 
     def __repr__(self):
-        return f"LoqusdbAPI(binary_path={Path(self.binary_path).stem}, config_path={Path(self.config_path).stem})"
+        return f"LoqusdbAPI(binary_path={Path(self.binary_path).name}, config_path={Path(self.config_path).name})"
