@@ -3,39 +3,39 @@
 import logging
 from pathlib import Path
 from subprocess import CalledProcessError
-from typing import List, Optional
 
 from cg.apps.scout.scout_export import ScoutExportCase, Variant
 from cg.constants.constants import FileFormat
 from cg.constants.gene_panel import GENOME_BUILD_37
-from cg.constants.scout_upload import ScoutCustomCaseReportTags
+from cg.constants.scout import ScoutCustomCaseReportTags
 from cg.exc import ScoutUploadError
 from cg.io.controller import ReadFile, ReadStream
 from cg.models.scout.scout_load_config import ScoutLoadConfig
+from cg.services.slurm_upload_service.slurm_upload_service import SlurmUploadService
 from cg.utils.commands import Process
 
 LOG = logging.getLogger(__name__)
 
 
 class ScoutAPI:
-
     """Interface to Scout."""
 
-    def __init__(self, config):
+    def __init__(self, config, slurm_upload_service: SlurmUploadService):
         binary_path = config["scout"]["binary_path"]
         config_path = config["scout"]["config_path"]
         self.process = Process(binary=binary_path, config=config_path)
+        self.slurm_upload_service = slurm_upload_service
+        self.scout_base_command = f"{binary_path} --config {config_path}"
 
-    def upload(self, scout_load_config: Path, force: bool = False):
+    def upload(self, scout_load_config: Path, force: bool = False) -> None:
         """Load analysis of a new family into Scout."""
 
         scout_config: dict = ReadFile.get_content_from_file(
             file_format=FileFormat.YAML, file_path=scout_load_config
         )
-        scout_load_config_object: ScoutLoadConfig = ScoutLoadConfig(**scout_config)
-        existing_case: Optional[ScoutExportCase] = self.get_case(
-            case_id=scout_load_config_object.family
-        )
+        scout_load_config_object = ScoutLoadConfig(**scout_config)
+        case_id: str = scout_load_config_object.family
+        existing_case: ScoutExportCase | None = self.get_case(case_id)
         load_command = ["load", "case", str(scout_load_config)]
         if existing_case:
             if force or scout_load_config_object.analysis_date > existing_case.analysis_date:
@@ -49,7 +49,9 @@ class ScoutAPI:
         self.process.run_command(load_command)
         LOG.debug("Case loaded successfully to Scout")
 
-    def export_panels(self, panels: List[str], build: str = GENOME_BUILD_37) -> List[str]:
+    def export_panels(
+        self, panels: list[str], build: str = GENOME_BUILD_37, dry_run: bool = False
+    ) -> list[str]:
         """Pass through to export of a list of gene panels.
 
         Return list of lines in bed format
@@ -61,7 +63,7 @@ class ScoutAPI:
             export_panels_command.extend(["--build", build])
 
         try:
-            self.process.run_command(export_panels_command)
+            self.process.run_command(export_panels_command, dry_run=dry_run)
             if not self.process.stdout:
                 return []
         except CalledProcessError:
@@ -70,7 +72,21 @@ class ScoutAPI:
 
         return list(self.process.stdout_lines())
 
-    def get_genes(self, panel_id: str, build: str = None) -> List[dict]:
+    def export_managed_variants(self, genome_build: str = GENOME_BUILD_37) -> list[str]:
+        """Export a list of managed variants."""
+        export_command = ["export", "managed"]
+        if genome_build:
+            export_command.extend(["--build", genome_build])
+        try:
+            self.process.run_command(export_command)
+            if not self.process.stdout:
+                return []
+        except CalledProcessError:
+            LOG.info("Could not export managed variants")
+            return []
+        return list(self.process.stdout_lines())
+
+    def get_genes(self, panel_id: str, build: str = None) -> list[dict]:
         """Return panel genes."""
         export_panel_command = ["export", "panel", panel_id]
         if build:
@@ -95,7 +111,7 @@ class ScoutAPI:
 
         return panel_genes
 
-    def get_causative_variants(self, case_id: str) -> List[Variant]:
+    def get_causative_variants(self, case_id: str) -> list[Variant]:
         """
         Get causative variants for a case.
         """
@@ -107,7 +123,7 @@ class ScoutAPI:
         except CalledProcessError:
             LOG.warning(f"Could not find case {case_id} in scout")
             return []
-        variants: List[Variant] = [
+        variants: list[Variant] = [
             Variant(**variant_info)
             for variant_info in ReadStream.get_content_from_stream(
                 file_format=FileFormat.JSON, stream=self.process.stdout
@@ -116,19 +132,19 @@ class ScoutAPI:
 
         return variants
 
-    def get_case(self, case_id: str) -> Optional[ScoutExportCase]:
+    def get_case(self, case_id: str) -> ScoutExportCase | None:
         """Fetch a case from Scout"""
-        cases: List[ScoutExportCase] = self.get_cases(case_id=case_id)
+        cases: list[ScoutExportCase] = self.get_cases(case_id=case_id)
         return cases[0] if cases else None
 
     def get_cases(
         self,
-        case_id: Optional[str] = None,
+        case_id: str | None = None,
         reruns: bool = False,
         finished: bool = False,
-        status: Optional[str] = None,
+        status: str | None = None,
         days_ago: int = None,
-    ) -> List[ScoutExportCase]:
+    ) -> list[ScoutExportCase]:
         """Interact with cases existing in the database."""
         get_cases_command = ["export", "cases", "--json"]
         if case_id:
@@ -141,7 +157,7 @@ class ScoutAPI:
             get_cases_command.append("--finished")
 
         if reruns:
-            LOG.info("Fetching cases that are reruns")
+            LOG.debug("Fetching cases that are reruns")
             get_cases_command.append("--reruns")
 
         if days_ago:
@@ -155,15 +171,15 @@ class ScoutAPI:
             LOG.info("Could not find cases")
             return []
 
-        cases: List[ScoutExportCase] = []
+        cases: list[ScoutExportCase] = []
         for case_export in ReadStream.get_content_from_stream(
             file_format=FileFormat.JSON, stream=self.process.stdout
         ):
-            LOG.info(f"Validating case {case_export.get('_id')}")
-            cases.append(ScoutExportCase(**case_export))
+            LOG.debug(f"Validating case {case_export.get('_id')}")
+            cases.append(ScoutExportCase.model_validate(case_export))
         return cases
 
-    def get_solved_cases(self, days_ago: int) -> List[ScoutExportCase]:
+    def get_solved_cases(self, days_ago: int) -> list[ScoutExportCase]:
         """
         Get cases solved within chosen time span.
         """
@@ -175,7 +191,7 @@ class ScoutAPI:
         If the user want to load a report that is already in the database
         'update' has to be 'True'."""
 
-        upload_command: List[str] = ["load", "delivery-report", case_id, report_path]
+        upload_command: list[str] = ["load", "delivery-report", case_id, report_path]
 
         if update:
             upload_command.append("--update")
@@ -189,7 +205,7 @@ class ScoutAPI:
     def upload_report(self, case_id: str, report_path: str, report_type: str) -> None:
         """Load report into a case in the database."""
 
-        upload_report_command: List[str] = [
+        upload_report_command: list[str] = [
             "load",
             "report",
             "-t",
@@ -214,26 +230,28 @@ class ScoutAPI:
         )
         self.upload_report(case_id=case_id, report_path=report_path, report_type=report_type)
 
-    def upload_splice_junctions_bed(self, file_path: str, case_id: str, customer_sample_id: str):
+    def upload_splice_junctions_bed(
+        self, file_path: str, case_id: str, customer_sample_id: str
+    ) -> None:
         """Load a splice junctions bed file into a case in the database."""
 
-        upload_command: List[str] = [
+        upload_command: list[str] = [
             "update",
             "individual",
-            "-c",
+            "--case-id",
             case_id,
-            "-n",
+            "--ind",
             customer_sample_id,
             "splice_junctions_bed",
             file_path,
         ]
 
         try:
-            LOG.info("Uploading splice junctions bed file {file_path} to case {case_id}")
+            LOG.info(f"Uploading splice junctions bed file {file_path} to case {case_id}.")
             self.process.run_command(upload_command)
         except CalledProcessError as error:
             raise ScoutUploadError(
-                "Something went wrong when uploading splice junctions bed file"
+                "Something went wrong when uploading the splice junctions bed file."
             ) from error
 
     def upload_rna_coverage_bigwig(
@@ -241,12 +259,12 @@ class ScoutAPI:
     ) -> None:
         """Load a rna coverage bigwig file into a case in the database."""
 
-        upload_command: List[str] = [
+        upload_command: list[str] = [
             "update",
             "individual",
-            "-c",
+            "--case-id",
             case_id,
-            "-n",
+            "--ind",
             customer_sample_id,
             "rna_coverage_bigwig",
             file_path,
@@ -259,3 +277,27 @@ class ScoutAPI:
             raise ScoutUploadError(
                 "Something went wrong when uploading rna coverage bigwig file"
             ) from error
+
+    def upload_rna_alignment_file(
+        self, case_id: str, customer_sample_id: str, file_path: str
+    ) -> None:
+        """Load an RNA alignment CRAM file into a case in the database."""
+
+        upload_command: list[str] = [
+            "update",
+            "individual",
+            "--case-id",
+            case_id,
+            "--ind",
+            customer_sample_id,
+            "rna_alignment_path",
+            file_path,
+        ]
+
+        try:
+            LOG.info(f"Uploading RNA alignment CRAM file {file_path} to case {case_id}")
+            self.process.run_command(upload_command)
+        except CalledProcessError as error:
+            raise ScoutUploadError(
+                "Something went wrong when uploading the RNA alignment CRAM file"
+            ) from error
