@@ -1,31 +1,34 @@
 import logging
-from typing import Optional, Tuple, List
 
 import click
-from cg.constants import STATUS_OPTIONS, DataDelivery, Pipeline
-from cg.constants.subject import Gender
+
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS, is_case_name_allowed
+from cg.constants import DataDelivery, Priority, Workflow
+from cg.constants.archiving import PDC_ARCHIVE_LOCATION
+from cg.constants.cli_options import DRY_RUN, FORCE
+from cg.constants.constants import StatusOptions
+from cg.constants.subject import Sex
 from cg.meta.transfer.external_data import ExternalDataAPI
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from cg.utils.click.EnumChoice import EnumChoice
 from cg.store.models import (
-    Family,
-    FamilySample,
-    Sample,
-    User,
-    Collaboration,
-    Customer,
     Application,
     ApplicationVersion,
+    Case,
+    CaseSample,
+    Collaboration,
+    Customer,
+    Order,
     Panel,
+    Sample,
+    User,
 )
-
-from cg.constants import Priority
+from cg.store.store import Store
+from cg.utils.click.EnumChoice import EnumChoice
 
 LOG = logging.getLogger(__name__)
 
 
-@click.group()
+@click.group(context_settings=CLICK_CONTEXT_SETTINGS)
 def add():
     """Add new things to the database."""
     pass
@@ -55,14 +58,36 @@ def add():
     required=True,
     help="Invoice reference (text)",
 )
+@click.option(
+    "-da",
+    "--data-archive-location",
+    "data_archive_location",
+    help="Specifies where to store data for the customer.",
+    default=PDC_ARCHIVE_LOCATION,
+    show_default=True,
+    required=False,
+)
+@click.option(
+    "-ic",
+    "--is-clinical",
+    "is_clinical",
+    help="Set to true to indicate that this customer is clinical"
+    " and handle data storage accordingly, i.e. for 10 years instead if 2 years.",
+    is_flag=True,
+    default=False,
+    show_default=True,
+    required=False,
+)
 @click.pass_obj
 def add_customer(
     context: CGConfig,
     internal_id: str,
     name: str,
-    collaboration_internal_ids: Optional[List[str]],
+    collaboration_internal_ids: list[str] | None,
     invoice_address: str,
     invoice_reference: str,
+    data_archive_location: str,
+    is_clinical: bool,
 ):
     """Add a new customer with a unique internal id and name."""
     collaboration_internal_ids = collaboration_internal_ids or []
@@ -75,7 +100,7 @@ def add_customer(
         LOG.error(f"{existing_customer.name}: customer already added")
         raise click.Abort
 
-    collaborations: List[Collaboration] = [
+    collaborations: list[Collaboration] = [
         status_db.get_collaboration_by_internal_id(internal_id=collaboration_internal_id)
         for collaboration_internal_id in collaboration_internal_ids
     ]
@@ -85,6 +110,8 @@ def add_customer(
         name=name,
         invoice_address=invoice_address,
         invoice_reference=invoice_reference,
+        data_archive_location=data_archive_location,
+        is_clinical=is_clinical,
     )
     for collaboration in collaborations:
         new_customer.collaborations.append(collaboration)
@@ -133,7 +160,7 @@ def add_user(context: CGConfig, admin: bool, customer_id: str, email: str, name:
 @click.option(
     "-s",
     "--sex",
-    type=EnumChoice(Gender, use_value=False),
+    type=EnumChoice(Sex, use_value=False),
     required=True,
     help="Sample pedigree sex",
 )
@@ -145,19 +172,23 @@ def add_user(context: CGConfig, admin: bool, customer_id: str, email: str, name:
     default="standard",
     help="Set the priority for the samples",
 )
+@click.option(
+    "-t", "--original-ticket", required=True, help="Original ticket this sample is associated to."
+)
 @click.argument("customer_id")
 @click.argument("name")
 @click.pass_obj
 def add_sample(
     context: CGConfig,
-    lims_id: Optional[str],
-    down_sampled: Optional[int],
-    sex: Gender,
-    order: Optional[str],
+    lims_id: str | None,
+    down_sampled: int | None,
+    sex: Sex,
+    order: str | None,
     application_tag: str,
     priority: Priority,
     customer_id: str,
     name: str,
+    original_ticket: str,
 ):
     """Add a sample for CUSTOMER_ID with a NAME (display)."""
     status_db: Store = context.status_db
@@ -169,8 +200,8 @@ def add_sample(
     application: Application = status_db.get_application_by_tag(tag=application_tag)
     if not application:
         LOG.error(f"Application: {application_tag} not found")
-
         raise click.Abort
+
     new_record: Sample = status_db.add_sample(
         name=name,
         sex=sex,
@@ -178,6 +209,7 @@ def add_sample(
         internal_id=lims_id,
         order=order,
         priority=priority,
+        original_ticket=original_ticket,
     )
     new_record.application_version: ApplicationVersion = (
         status_db.get_current_application_version_by_tag(tag=application_tag)
@@ -202,7 +234,7 @@ def add_sample(
     "data_analysis",
     help="Analysis workflow",
     required=True,
-    type=EnumChoice(Pipeline),
+    type=EnumChoice(Workflow),
 )
 @click.option(
     "-dd",
@@ -219,8 +251,8 @@ def add_sample(
 def add_case(
     context: CGConfig,
     priority: Priority,
-    panel_abbreviations: Tuple[str],
-    data_analysis: Pipeline,
+    panel_abbreviations: tuple[str],
+    data_analysis: Workflow,
     data_delivery: DataDelivery,
     customer_id: str,
     name: str,
@@ -241,7 +273,11 @@ def add_case(
             LOG.error(f"{panel_abbreviation}: panel not found")
             raise click.Abort
 
-    new_case: Family = status_db.add_case(
+    if not is_case_name_allowed(name):
+        LOG.error(f"Case name {name} is only allowed to contain letters, digits and dashes.")
+        raise click.Abort
+
+    new_case: Case = status_db.add_case(
         data_analysis=data_analysis,
         data_delivery=data_delivery,
         name=name,
@@ -249,6 +285,16 @@ def add_case(
         priority=priority,
         ticket=ticket,
     )
+    order: Order = status_db.get_order_by_ticket_id(int(ticket))
+    if not order:
+        LOG.warning(f"No order found with ticket_id {ticket}")
+        click.confirm("No order found for the given ticket, proceed?", default=False, abort=True)
+        order = Order(
+            customer_id=customer.id,
+            ticket_id=int(ticket),
+            workflow=data_analysis,
+        )
+    new_case.orders.append(order)
 
     new_case.customer: Customer = customer
     status_db.session.add(new_case)
@@ -259,50 +305,50 @@ def add_case(
 @add.command("relationship")
 @click.option("-m", "--mother-id", help="Sample ID for mother of sample")
 @click.option("-f", "--father-id", help="Sample ID for father of sample")
-@click.option("-s", "--status", type=click.Choice(STATUS_OPTIONS), required=True)
+@click.option("-s", "--status", type=EnumChoice(StatusOptions), required=True)
 @click.argument("case-id")
 @click.argument("sample-id")
 @click.pass_obj
 def link_sample_to_case(
     context: CGConfig,
-    mother_id: Optional[str],
-    father_id: Optional[str],
+    mother_id: str | None,
+    father_id: str | None,
     status: str,
     case_id: str,
     sample_id: str,
 ):
     """Create a link between a case id and a sample id."""
     status_db: Store = context.status_db
-    mother: Optional[Sample] = None
-    father: Optional[Sample] = None
-    case_obj: Family = status_db.get_case_by_internal_id(internal_id=case_id)
+    mother: Sample | None = None
+    father: Sample | None = None
+    case_obj: Case = status_db.get_case_by_internal_id(internal_id=case_id)
     if case_obj is None:
-        LOG.error("%s: family not found", case_id)
+        LOG.error(f"{case_id}: family not found")
         raise click.Abort
 
     sample: Sample = status_db.get_sample_by_internal_id(internal_id=sample_id)
     if sample is None:
-        LOG.error("%s: sample not found", sample_id)
+        LOG.error(f"{sample_id}: sample not found")
         raise click.Abort
 
     if mother_id:
         mother: Sample = status_db.get_sample_by_internal_id(internal_id=mother_id)
         if mother is None:
-            LOG.error("%s: mother not found", mother_id)
+            LOG.error(f"{mother_id}: mother not found")
             raise click.Abort
 
     if father_id:
         father: Sample = status_db.get_sample_by_internal_id(internal_id=father_id)
         if father is None:
-            LOG.error("%s: father not found", father_id)
+            LOG.error(f"{father_id}: father not found")
             raise click.Abort
 
-    new_record: FamilySample = status_db.relate_sample(
-        family=case_obj, sample=sample, status=status, mother=mother, father=father
+    new_record: CaseSample = status_db.relate_sample(
+        case=case_obj, sample=sample, status=status, mother=mother, father=father
     )
     status_db.session.add(new_record)
     status_db.session.commit()
-    LOG.info("related %s to %s", case_obj.internal_id, sample.internal_id)
+    LOG.info(f"related {case_id} to {sample_id}")
 
 
 @add.command("external")
@@ -313,7 +359,7 @@ def link_sample_to_case(
     help="Ticket id",
     required=True,
 )
-@click.option("--dry-run", is_flag=True)
+@DRY_RUN
 @click.pass_obj
 def download_external_delivery_data_to_hpc(context: CGConfig, ticket: str, dry_run: bool):
     """Downloads external data from the delivery server and places it in appropriate folder on
@@ -330,12 +376,10 @@ def download_external_delivery_data_to_hpc(context: CGConfig, ticket: str, dry_r
     help="Ticket id",
     required=True,
 )
-@click.option("--dry-run", is_flag=True)
-@click.option(
-    "--force", help="Overwrites any any previous samples in the customer directory", is_flag=True
-)
+@DRY_RUN
+@FORCE
 @click.pass_obj
-def add_external_data_to_hk(context: CGConfig, ticket: str, dry_run: bool, force):
+def add_external_data_to_hk(context: CGConfig, ticket: str, dry_run: bool, force: bool):
     """Adds external data to Housekeeper"""
     external_data_api = ExternalDataAPI(config=context)
-    external_data_api.add_transfer_to_housekeeper(dry_run=dry_run, ticket=ticket, force=force)
+    external_data_api.add_external_data_to_housekeeper(ticket=ticket, dry_run=dry_run, force=force)
