@@ -1,44 +1,43 @@
 """CLI support to create config and/or start BALSAMIC."""
 
 import logging
-from typing import List
 
 import click
+from pydantic.v1 import ValidationError
+
 from cg.apps.housekeeper.hk import HousekeeperAPI
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.balsamic.options import (
-    OPTION_PANEL_BED,
-    OPTION_QOS,
-    OPTION_RUN_ANALYSIS,
-    OPTION_GENOME_VERSION,
-    OPTION_PON_CNN,
+    OPTION_CACHE_VERSION,
+    OPTION_CLUSTER_CONFIG,
     OPTION_GENDER,
+    OPTION_GENOME_VERSION,
     OPTION_OBSERVATIONS,
-    OPTION_FORCE_NORMAL,
+    OPTION_PANEL_BED,
+    OPTION_PON_CNN,
+    OPTION_QOS,
 )
-from cg.cli.workflow.commands import link, resolve_compression, ARGUMENT_CASE_ID
+from cg.cli.workflow.commands import ARGUMENT_CASE_ID, link, resolve_compression
+from cg.cli.workflow.utils import validate_force_store_option
 from cg.constants import EXIT_FAIL, EXIT_SUCCESS
-from cg.constants.constants import DRY_RUN
-from cg.exc import CgError, DecompressionNeededError
+from cg.constants.cli_options import DRY_RUN, FORCE, COMMENT
+from cg.exc import AnalysisNotReadyError, CgError
 from cg.meta.workflow.analysis import AnalysisAPI
 from cg.meta.workflow.balsamic import BalsamicAnalysisAPI
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from pydantic import ValidationError
-
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
 
-@click.group(invoke_without_command=True)
+@click.group(invoke_without_command=True, context_settings=CLICK_CONTEXT_SETTINGS)
 @click.pass_context
 def balsamic(context: click.Context):
     """Cancer analysis workflow"""
     AnalysisAPI.get_help(context)
 
     config = context.obj
-    context.obj.meta_apis["analysis_api"] = BalsamicAnalysisAPI(
-        config=config,
-    )
+    context.obj.meta_apis["analysis_api"] = BalsamicAnalysisAPI(config=config)
 
 
 balsamic.add_command(resolve_compression)
@@ -52,7 +51,7 @@ balsamic.add_command(link)
 @OPTION_PANEL_BED
 @OPTION_PON_CNN
 @OPTION_OBSERVATIONS
-@OPTION_FORCE_NORMAL
+@OPTION_CACHE_VERSION
 @DRY_RUN
 @click.pass_obj
 def config_case(
@@ -62,8 +61,8 @@ def config_case(
     genome_version: str,
     panel_bed: str,
     pon_cnn: click.Path,
-    observations: List[click.Path],
-    force_normal: bool,
+    observations: list[click.Path],
+    cache_version: str,
     dry_run: bool,
 ):
     """Create config file for BALSAMIC analysis for a given CASE_ID."""
@@ -79,7 +78,7 @@ def config_case(
             panel_bed=panel_bed,
             pon_cnn=pon_cnn,
             observations=observations,
-            force_normal=force_normal,
+            cache_version=cache_version,
             dry_run=dry_run,
         )
     except CgError as error:
@@ -92,30 +91,30 @@ def config_case(
 
 @balsamic.command("run")
 @ARGUMENT_CASE_ID
+@OPTION_CLUSTER_CONFIG
 @DRY_RUN
 @OPTION_QOS
-@OPTION_RUN_ANALYSIS
 @click.pass_obj
 def run(
     context: CGConfig,
-    run_analysis: bool,
-    slurm_quality_of_service: str,
     case_id: str,
+    cluster_config: click.Path,
+    slurm_quality_of_service: str,
     dry_run: bool,
 ):
     """Run balsamic analysis for given CASE ID"""
     analysis_api: AnalysisAPI = context.meta_apis["analysis_api"]
     try:
         analysis_api.status_db.verify_case_exists(case_internal_id=case_id)
-        analysis_api.verify_case_config_file_exists(case_id=case_id)
+        analysis_api.verify_case_config_file_exists(case_id=case_id, dry_run=dry_run)
         analysis_api.check_analysis_ongoing(case_id)
         analysis_api.run_analysis(
             case_id=case_id,
-            run_analysis=run_analysis,
+            cluster_config=cluster_config,
             slurm_quality_of_service=slurm_quality_of_service,
             dry_run=dry_run,
         )
-        if dry_run or not run_analysis:
+        if dry_run:
             return
         analysis_api.add_pending_trailblazer_analysis(case_id=case_id)
         analysis_api.set_statusdb_action(case_id=case_id, action="running")
@@ -130,16 +129,17 @@ def run(
 @balsamic.command("report-deliver")
 @ARGUMENT_CASE_ID
 @DRY_RUN
+@FORCE
 @click.pass_obj
-def report_deliver(context: CGConfig, case_id: str, dry_run: bool):
-    """Create a housekeeper deliverables file for given CASE ID"""
-
+def report_deliver(context: CGConfig, case_id: str, dry_run: bool, force: bool):
+    """Create a Housekeeper deliverables file for a given case ID."""
     analysis_api: AnalysisAPI = context.meta_apis["analysis_api"]
-
     try:
-        analysis_api.status_db.verify_case_exists(case_internal_id=case_id)
-        analysis_api.verify_case_config_file_exists(case_id=case_id)
-        analysis_api.trailblazer_api.is_latest_analysis_completed(case_id=case_id)
+        analysis_api.status_db.verify_case_exists(case_id)
+        analysis_api.verify_case_config_file_exists(case_id=case_id, dry_run=dry_run)
+        analysis_api.trailblazer_api.verify_latest_analysis_is_completed(
+            case_id=case_id, force=force
+        )
         analysis_api.report_deliver(case_id=case_id, dry_run=dry_run)
     except CgError as error:
         LOG.error(f"Could not create report file: {error}")
@@ -151,8 +151,13 @@ def report_deliver(context: CGConfig, case_id: str, dry_run: bool):
 
 @balsamic.command("store-housekeeper")
 @ARGUMENT_CASE_ID
+@COMMENT
+@DRY_RUN
+@FORCE
 @click.pass_obj
-def store_housekeeper(context: CGConfig, case_id: str):
+def store_housekeeper(
+    context: CGConfig, case_id: str, comment: str | None, dry_run: bool, force: bool
+):
     """Store a finished analysis in Housekeeper and StatusDB."""
 
     analysis_api: AnalysisAPI = context.meta_apis["analysis_api"]
@@ -161,11 +166,13 @@ def store_housekeeper(context: CGConfig, case_id: str):
 
     try:
         analysis_api.status_db.verify_case_exists(case_internal_id=case_id)
-        analysis_api.verify_case_config_file_exists(case_id=case_id)
+        analysis_api.verify_case_config_file_exists(case_id=case_id, dry_run=dry_run)
         analysis_api.verify_deliverables_file_exists(case_id=case_id)
-        analysis_api.upload_bundle_housekeeper(case_id=case_id)
-        analysis_api.upload_bundle_statusdb(case_id=case_id)
-        analysis_api.set_statusdb_action(case_id=case_id, action=None)
+        analysis_api.upload_bundle_housekeeper(case_id=case_id, dry_run=dry_run, force=force)
+        analysis_api.upload_bundle_statusdb(
+            case_id=case_id, comment=comment, dry_run=dry_run, force=force
+        )
+        analysis_api.set_statusdb_action(case_id=case_id, action=None, dry_run=dry_run)
     except ValidationError as error:
         LOG.warning("Deliverables file is malformed")
         raise error
@@ -187,45 +194,46 @@ def store_housekeeper(context: CGConfig, case_id: str):
 @DRY_RUN
 @OPTION_PANEL_BED
 @OPTION_PON_CNN
-@OPTION_RUN_ANALYSIS
-@OPTION_FORCE_NORMAL
+@OPTION_CACHE_VERSION
+@OPTION_OBSERVATIONS
+@OPTION_CLUSTER_CONFIG
 @click.pass_context
 def start(
     context: click.Context,
     case_id: str,
     gender: str,
     genome_version: str,
+    cache_version: str,
     panel_bed: str,
     pon_cnn: str,
+    observations: list[click.Path],
     slurm_quality_of_service: str,
-    run_analysis: bool,
-    force_normal: bool,
+    cluster_config: click.Path,
     dry_run: bool,
 ):
-    """Start full workflow for CASE ID"""
+    """Start full workflow for case ID."""
+    analysis_api: BalsamicAnalysisAPI = context.obj.meta_apis["analysis_api"]
+    analysis_api.prepare_fastq_files(case_id=case_id, dry_run=dry_run)
     LOG.info(f"Starting analysis for {case_id}")
-    try:
-        context.invoke(resolve_compression, case_id=case_id, dry_run=dry_run)
-        context.invoke(link, case_id=case_id, dry_run=dry_run)
-        context.invoke(
-            config_case,
-            case_id=case_id,
-            gender=gender,
-            genome_version=genome_version,
-            panel_bed=panel_bed,
-            pon_cnn=pon_cnn,
-            force_normal=force_normal,
-            dry_run=dry_run,
-        )
-        context.invoke(
-            run,
-            case_id=case_id,
-            slurm_quality_of_service=slurm_quality_of_service,
-            run_analysis=run_analysis,
-            dry_run=dry_run,
-        )
-    except DecompressionNeededError as error:
-        LOG.error(error)
+    context.invoke(link, case_id=case_id, dry_run=dry_run)
+    context.invoke(
+        config_case,
+        case_id=case_id,
+        gender=gender,
+        genome_version=genome_version,
+        cache_version=cache_version,
+        panel_bed=panel_bed,
+        pon_cnn=pon_cnn,
+        observations=observations,
+        dry_run=dry_run,
+    )
+    context.invoke(
+        run,
+        case_id=case_id,
+        cluster_config=cluster_config,
+        slurm_quality_of_service=slurm_quality_of_service,
+        dry_run=dry_run,
+    )
 
 
 @balsamic.command("start-available")
@@ -237,14 +245,16 @@ def start_available(context: click.Context, dry_run: bool = False):
     analysis_api: AnalysisAPI = context.obj.meta_apis["analysis_api"]
 
     exit_code: int = EXIT_SUCCESS
-    for case_obj in analysis_api.get_cases_to_analyze():
+    for case in analysis_api.get_cases_ready_for_analysis():
         try:
-            context.invoke(start, case_id=case_obj.internal_id, dry_run=dry_run, run_analysis=True)
+            context.invoke(start, case_id=case.internal_id, dry_run=dry_run)
+        except AnalysisNotReadyError as error:
+            LOG.error(error)
         except CgError as error:
             LOG.error(error)
             exit_code = EXIT_FAIL
         except Exception as error:
-            LOG.error("Unspecified error occurred: %s", error)
+            LOG.error(f"Unspecified error occurred: {error}")
             exit_code = EXIT_FAIL
     if exit_code:
         raise click.Abort
@@ -252,13 +262,16 @@ def start_available(context: click.Context, dry_run: bool = False):
 
 @balsamic.command("store")
 @ARGUMENT_CASE_ID
+@COMMENT
 @DRY_RUN
+@FORCE
 @click.pass_context
-def store(context: click.Context, case_id: str, dry_run: bool):
+def store(context: click.Context, case_id: str, comment: str | None, dry_run: bool, force: bool):
     """Generate Housekeeper report for CASE ID and store in Housekeeper"""
     LOG.info(f"Storing analysis for {case_id}")
-    context.invoke(report_deliver, case_id=case_id, dry_run=dry_run)
-    context.invoke(store_housekeeper, case_id=case_id)
+    validate_force_store_option(force=force, comment=comment)
+    context.invoke(report_deliver, case_id=case_id, dry_run=dry_run, force=force)
+    context.invoke(store_housekeeper, case_id=case_id, comment=comment, force=force)
 
 
 @balsamic.command("store-available")
@@ -271,11 +284,11 @@ def store_available(context: click.Context, dry_run: bool) -> None:
 
     exit_code: int = EXIT_SUCCESS
     for case_obj in analysis_api.get_cases_to_store():
-        LOG.info("Storing deliverables for %s", case_obj.internal_id)
+        LOG.info(f"Storing deliverables for {case_obj.internal_id}")
         try:
             context.invoke(store, case_id=case_obj.internal_id, dry_run=dry_run)
         except Exception as exception_object:
-            LOG.error("Error storing %s: %s", case_obj.internal_id, exception_object)
+            LOG.error(f"Error storing {case_obj.internal_id}: {exception_object}")
             exit_code = EXIT_FAIL
     if exit_code:
         raise click.Abort
