@@ -3,16 +3,20 @@
 import logging
 
 import click
+
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.balsamic.base import config_case, run, start
-
-from cg.cli.workflow.commands import resolve_compression, link
-
+from cg.cli.workflow.commands import link, resolve_compression
 from cg.meta.workflow.balsamic_pon import BalsamicPonAnalysisAPI
 
 LOG = logging.getLogger(__name__)
 
 
-@click.group("balsamic-pon", invoke_without_command=True)
+@click.group(
+    "balsamic-pon",
+    invoke_without_command=True,
+    context_settings=CLICK_CONTEXT_SETTINGS,
+)
 @click.pass_context
 def balsamic_pon(context: click.Context):
     """Cancer PON analysis workflow"""
