@@ -4,15 +4,16 @@ import logging
 
 import click
 
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.balsamic.base import (
     config_case,
-    run,
     report_deliver,
-    store_housekeeper,
+    run,
     start,
     start_available,
     store,
     store_available,
+    store_housekeeper,
 )
 from cg.cli.workflow.commands import link, resolve_compression
 from cg.meta.workflow.balsamic_umi import BalsamicUmiAnalysisAPI
@@ -20,7 +21,11 @@ from cg.meta.workflow.balsamic_umi import BalsamicUmiAnalysisAPI
 LOG = logging.getLogger(__name__)
 
 
-@click.group("balsamic-umi", invoke_without_command=True)
+@click.group(
+    "balsamic-umi",
+    invoke_without_command=True,
+    context_settings=CLICK_CONTEXT_SETTINGS,
+)
 @click.pass_context
 def balsamic_umi(context: click.Context):
     """Cancer analysis workflow"""
@@ -28,9 +33,7 @@ def balsamic_umi(context: click.Context):
         click.echo(context.get_help())
         return None
     config = context.obj
-    context.obj.meta_apis["analysis_api"] = BalsamicUmiAnalysisAPI(
-        config=config,
-    )
+    context.obj.meta_apis["analysis_api"] = BalsamicUmiAnalysisAPI(config=config)
 
 
 balsamic_umi.add_command(resolve_compression)
