@@ -3,15 +3,17 @@
 import logging
 
 import click
+
+from cg.cli.utils import CLICK_CONTEXT_SETTINGS
 from cg.cli.workflow.commands import link, resolve_compression, store, store_available
 from cg.cli.workflow.mip.base import config_case, panel, run, start, start_available
-from cg.meta.workflow.mip_rna import MipRNAAnalysisAPI
 from cg.meta.workflow.analysis import AnalysisAPI
+from cg.meta.workflow.mip_rna import MipRNAAnalysisAPI
 
 LOG = logging.getLogger(__name__)
 
 
-@click.group("mip-rna")
+@click.group("mip-rna", context_settings=CLICK_CONTEXT_SETTINGS)
 @click.pass_context
 def mip_rna(context: click.Context):
     """Rare disease RNA workflow"""
