@@ -245,3 +245,8 @@ class JanusTags:
         "star",
         "general-stats",
     ]
+
+
+class FohmTag(StrEnum):
+    COMPLEMENTARY = "komplettering"
+    PANGOLIN_TYPING = "pangolin-typing-fohm"
