@@ -1,7 +1,6 @@
 """Priority specific constants"""
-from enum import IntEnum
 
-from cg.utils.enums import StrEnum
+from enum import IntEnum, StrEnum
 
 
 class SlurmQos(StrEnum):
@@ -20,12 +19,6 @@ class PriorityTerms(StrEnum):
     CLINICAL_TRIALS: str = "clinical_trials"
 
 
-SLURM_ACCOUNT_TO_QOS = {
-    "production": SlurmQos.NORMAL,
-    "development": SlurmQos.LOW,
-}
-
-
 class Priority(IntEnum):
     research: int = 0
     standard: int = 1
@@ -33,11 +26,18 @@ class Priority(IntEnum):
     express: int = 3
     clinical_trials: int = 4
 
+    @classmethod
+    def priority_to_slurm_qos(cls) -> dict[int, str]:
+        return {
+            Priority.research: SlurmQos.LOW,
+            Priority.standard: SlurmQos.NORMAL,
+            Priority.priority: SlurmQos.HIGH,
+            Priority.express: SlurmQos.EXPRESS,
+            Priority.clinical_trials: SlurmQos.NORMAL,
+        }
 
-PRIORITY_TO_SLURM_QOS = {
-    Priority.research: SlurmQos.LOW,
-    Priority.standard: SlurmQos.NORMAL,
-    Priority.priority: SlurmQos.HIGH,
-    Priority.express: SlurmQos.EXPRESS,
-    Priority.clinical_trials: SlurmQos.NORMAL,
-}
+
+class SlurmAccount(StrEnum):
+    PRODUCTION: str = "production"
+    DEVELOPMENT: str = "development"
+    STAGE: str = "stage"
