@@ -1,17 +1,22 @@
+from typing import Any
+
+from pydantic.v1 import ValidationError
+
 from cg.apps.lims import LimsAPI
-from cg.server.ext import lims as genologics_lims
-from cg.server.ext import FlaskLims
-from cg.store import Store
-from typing import Optional, Union, List, Any
-from cg.store.models import Invoice, Customer, User, Sample, Pool
+from cg.constants.constants import CustomerId
+from cg.constants.invoice import CostCenters
 from cg.constants.priority import PriorityTerms
 from cg.constants.sequencing import RecordType
-from cg.constants.invoice import (
-    CostCenters,
-    CustomerNames,
+from cg.models.invoice.invoice import (
+    InvoiceApplication,
+    InvoiceContact,
+    InvoiceInfo,
+    InvoiceReport,
 )
-from cg.models.invoice.invoice import InvoiceContact, InvoiceApplication, InvoiceReport, InvoiceInfo
-from pydantic import ValidationError
+from cg.server.ext import FlaskLims
+from cg.server.ext import lims as genologics_lims
+from cg.store.models import Customer, Invoice, Pool, Sample, User
+from cg.store.store import Store
 
 
 class InvoiceAPI:
@@ -25,7 +30,7 @@ class InvoiceAPI:
         self.raw_records = []
         self._set_record_type()
         self.genologics_lims: FlaskLims = genologics_lims
-        self.invoice_info: Optional[InvoiceInfo] = None
+        self.invoice_info: InvoiceInfo | None = None
 
     def _set_record_type(self):
         """Define the record_type based on the invoice object.
@@ -37,10 +42,10 @@ class InvoiceAPI:
             self.record_type = RecordType.Sample
             self.raw_records = self.invoice_obj.samples
 
-    def get_customer_by_cost_center(self, cost_center: str) -> Union[Customer, str]:
+    def get_customer_by_cost_center(self, cost_center: str) -> Customer | str:
         """Return the costumer based on cost center."""
         return (
-            self.db.get_customer_by_internal_id(customer_internal_id=CustomerNames.cust999)
+            self.db.get_customer_by_internal_id(customer_internal_id=CustomerId.CUST999)
             if cost_center.lower() == CostCenters.kth
             else self.customer_obj
         )
@@ -53,8 +58,8 @@ class InvoiceAPI:
         return customer.invoice_contact
 
     def get_contact(
-        self, customer: Customer, customer_invoice_contact: Optional[User], msg: str
-    ) -> Optional[InvoiceContact]:
+        self, customer: Customer, customer_invoice_contact: User | None, msg: str
+    ) -> InvoiceContact | None:
         """Return the contact information."""
         try:
             contact = InvoiceContact(
@@ -70,7 +75,7 @@ class InvoiceAPI:
             self.log.append(msg)
             return None
 
-    def get_contact_info(self, cost_center: str) -> Optional[InvoiceContact]:
+    def get_contact_info(self, cost_center: str) -> InvoiceContact | None:
         """Return contact info for a customer."""
 
         msg = (
@@ -83,11 +88,11 @@ class InvoiceAPI:
             customer_invoice_contact=customer_invoice_contact, customer=customer, msg=msg
         )
 
-    def get_invoice_report(self, cost_center: str) -> Optional[dict]:
+    def get_invoice_report(self, cost_center: str) -> dict | None:
         """Return invoice information as dictionary to generate Excel report."""
 
-        records: List[dict] = []
-        pooled_samples: List = []
+        records: list[dict] = []
+        pooled_samples = []
 
         for raw_record in self.raw_records:
             if self.record_type == RecordType.Pool:
@@ -127,7 +132,7 @@ class InvoiceAPI:
             self.log.append("ValidationError in InvoiceReport class.")
             return None
 
-    def _discount_price(self, record: Sample or Pool, discount: int = 0) -> Optional[int]:
+    def _discount_price(self, record: Sample or Pool, discount: int = 0) -> int | None:
         """Return discount price for a sample or pool."""
         priority = self.get_priority(record, for_discount_price=True)
         full_price = getattr(record.application_version, f"price_{priority}")
@@ -138,7 +143,7 @@ class InvoiceAPI:
 
     def _cost_center_split_factor(
         self, price: int, cost_center: str, percent_kth: int, tag: str, version: str
-    ) -> Optional[int]:
+    ) -> int | None:
         """Return split price based on cost center."""
         if price:
             try:
@@ -182,9 +187,7 @@ class InvoiceAPI:
 
         return invoice_info
 
-    def get_application(
-        self, record: Sample or Pool, discount: int
-    ) -> Optional[InvoiceApplication]:
+    def get_application(self, record: Sample or Pool, discount: int) -> InvoiceApplication | None:
         """Return the application information."""
         try:
             application = InvoiceApplication(
@@ -210,7 +213,7 @@ class InvoiceAPI:
 
     def get_priority(self, record: Sample or Pool, for_discount_price: bool = False) -> str:
         """Return the priority."""
-        if self.customer_obj.internal_id == CustomerNames.cust032:
+        if self.customer_obj.internal_id == CustomerId.CUST032:
             priority = PriorityTerms.STANDARD
         elif self.record_type == RecordType.Pool or (
             record.priority_human == "clinical trials" and for_discount_price
@@ -261,7 +264,7 @@ class InvoiceAPI:
         """Set invoice_info."""
         self.invoice_info = invoice_info
 
-    def total_price(self) -> Optional[float]:
+    def total_price(self) -> float | None:
         """Return the total price for all records in the invoice."""
 
         discount = self.invoice_obj.discount
