@@ -18,6 +18,7 @@ from cg.models.cg_config import CGConfig, CommonAppConfig
 from cg.models.observations.input_files import (
     BalsamicObservationsInputFiles,
     MipDNAObservationsInputFiles,
+    RarediseaseObservationsInputFiles,
 )
 from cg.store.models import Analysis, Case
 from cg.store.store import Store
@@ -56,8 +57,12 @@ class ObservationsAPI:
 
     def get_observations_input_files(
         self, case: Case
-    ) -> MipDNAObservationsInputFiles | BalsamicObservationsInputFiles:
-        """Fetch input files from a case to upload to Loqusdb."""
+    ) -> (
+        BalsamicObservationsInputFiles
+        | MipDNAObservationsInputFiles
+        | RarediseaseObservationsInputFiles
+    ):
+        """Return input files from a case to upload to Loqusdb."""
         analysis: Analysis = case.analyses[0]
         analysis_date: datetime = analysis.started_at or analysis.completed_at
         hk_version: Version = self.housekeeper_api.version(analysis.case.internal_id, analysis_date)
