@@ -16,7 +16,10 @@ from cg.constants.scout import ScoutUploadKey
 from cg.exc import DeliveryReportError
 from cg.io.controller import ReadFile, WriteStream
 from cg.meta.meta import MetaAPI
-from cg.meta.report.field_validators import get_empty_report_data, get_missing_report_data
+from cg.meta.report.field_validators import (
+    get_empty_report_data,
+    get_missing_report_data,
+)
 from cg.meta.workflow.analysis import AnalysisAPI
 from cg.models.analysis import AnalysisModel
 from cg.models.cg_config import CGConfig
@@ -28,8 +31,20 @@ from cg.models.report.report import (
     ReportModel,
     ScoutReportFiles,
 )
-from cg.models.report.sample import ApplicationModel, MethodsModel, SampleModel, TimestampModel
-from cg.store.models import Analysis, Application, ApplicationLimitations, Case, CaseSample, Sample
+from cg.models.report.sample import (
+    ApplicationModel,
+    MethodsModel,
+    SampleModel,
+    TimestampModel,
+)
+from cg.store.models import (
+    Analysis,
+    Application,
+    ApplicationLimitations,
+    Case,
+    CaseSample,
+    Sample,
+)
 
 LOG = logging.getLogger(__name__)
 
