@@ -5,7 +5,7 @@ from subprocess import CalledProcessError
 
 import click
 
-from cg.cli.upload.clinical_delivery import upload_clinical_delivery
+
 from cg.cli.upload.scout import upload_rna_to_scout
 from cg.constants import DataDelivery
 from cg.meta.upload.upload_api import UploadAPI
@@ -28,8 +28,7 @@ class MipRNAUploadAPI(UploadAPI):
         analysis: Analysis = case.analyses[0]
         self.update_upload_started_at(analysis=analysis)
 
-        # Clinical delivery upload
-        ctx.invoke(upload_clinical_delivery, case_id=case.internal_id)
+        self.upload_files_to_customer_inbox(case=case)
 
         # Scout specific upload
         if DataDelivery.SCOUT in case.data_delivery:
