@@ -1,20 +1,24 @@
 import logging
 import re
 from pathlib import Path
-from typing import Optional
 
 from housekeeper.store.models import Version
 
 from cg.apps.lims import LimsAPI
 from cg.apps.madeline.api import MadelineAPI
-from cg.constants.scout_upload import MIP_CASE_TAGS, MIP_SAMPLE_TAGS
+from cg.constants.housekeeper_tags import HK_DELIVERY_REPORT_TAG
+from cg.constants.scout import MIP_CASE_TAGS, MIP_SAMPLE_TAGS, UploadTrack
 from cg.constants.subject import RelationshipStatus
 from cg.meta.upload.scout.hk_tags import CaseTags, SampleTags
 from cg.meta.upload.scout.scout_config_builder import ScoutConfigBuilder
 from cg.meta.workflow.mip import MipAnalysisAPI
 from cg.models.mip.mip_analysis import MipAnalysis
-from cg.models.scout.scout_load_config import MipLoadConfig, ScoutLoadConfig, ScoutMipIndividual
-from cg.store.models import Analysis, Family, FamilySample
+from cg.models.scout.scout_load_config import (
+    MipLoadConfig,
+    ScoutLoadConfig,
+    ScoutMipIndividual,
+)
+from cg.store.models import Analysis, Case, CaseSample
 
 LOG = logging.getLogger(__name__)
 
@@ -33,7 +37,10 @@ class MipConfigBuilder(ScoutConfigBuilder):
         )
         self.case_tags: CaseTags = CaseTags(**MIP_CASE_TAGS)
         self.sample_tags: SampleTags = SampleTags(**MIP_SAMPLE_TAGS)
-        self.load_config: MipLoadConfig = MipLoadConfig(track="rare")
+        self.load_config: MipLoadConfig = MipLoadConfig(
+            track=UploadTrack.RARE_DISEASE.value,
+            delivery_report=self.get_file_from_hk({HK_DELIVERY_REPORT_TAG}),
+        )
         self.mip_analysis_api: MipAnalysisAPI = mip_analysis_api
         self.lims_api: LimsAPI = lims_api
         self.madeline_api: MadelineAPI = madeline_api
@@ -44,7 +51,7 @@ class MipConfigBuilder(ScoutConfigBuilder):
 
         self.add_common_info_to_load_config()
         mip_analysis_data: MipAnalysis = self.mip_analysis_api.get_latest_metadata(
-            self.analysis_obj.family.internal_id
+            self.analysis_obj.case.internal_id
         )
         self.load_config.human_genome_build = (
             "38" if "38" in mip_analysis_data.genome_build else "37"
@@ -54,8 +61,9 @@ class MipConfigBuilder(ScoutConfigBuilder):
         self.load_config.sv_rank_model_version = mip_analysis_data.sv_rank_model_version
 
         self.load_config.gene_panels = (
-            self.mip_analysis_api.convert_panels(
-                self.analysis_obj.family.customer.internal_id, self.analysis_obj.family.panels
+            self.mip_analysis_api.get_aggregated_panels(
+                customer_id=self.analysis_obj.case.customer.internal_id,
+                default_panels=set(self.analysis_obj.case.panels),
             )
             or None
         )
@@ -63,22 +71,22 @@ class MipConfigBuilder(ScoutConfigBuilder):
         self.include_case_files()
 
         LOG.info("Building samples")
-        db_sample: FamilySample
-        for db_sample in self.analysis_obj.family.links:
+        db_sample: CaseSample
+        for db_sample in self.analysis_obj.case.links:
             self.load_config.samples.append(self.build_config_sample(case_sample=db_sample))
         self.include_pedigree_picture()
 
     def include_pedigree_picture(self) -> None:
         if self.is_multi_sample_case(self.load_config):
             if self.is_family_case(self.load_config):
-                svg_path: Path = self.run_madeline(self.analysis_obj.family)
+                svg_path: Path = self.run_madeline(self.analysis_obj.case)
                 self.load_config.madeline = str(svg_path)
             else:
                 LOG.info("family of unconnected samples - skip pedigree graph")
         else:
             LOG.info("family of 1 sample - skip pedigree graph")
 
-    def build_config_sample(self, case_sample: FamilySample) -> ScoutMipIndividual:
+    def build_config_sample(self, case_sample: CaseSample) -> ScoutMipIndividual:
         """Build a sample with mip specific information"""
 
         config_sample = ScoutMipIndividual()
@@ -87,12 +95,12 @@ class MipConfigBuilder(ScoutConfigBuilder):
         config_sample.father = (
             case_sample.father.internal_id
             if case_sample.father
-            else RelationshipStatus.HAS_NO_PARENT.value
+            else RelationshipStatus.HAS_NO_PARENT
         )
         config_sample.mother = (
             case_sample.mother.internal_id
             if case_sample.mother
-            else RelationshipStatus.HAS_NO_PARENT.value
+            else RelationshipStatus.HAS_NO_PARENT
         )
 
         return config_sample
@@ -112,7 +120,6 @@ class MipConfigBuilder(ScoutConfigBuilder):
         self.load_config.vcf_sv = self.get_file_from_hk(self.case_tags.sv_vcf)
         self.load_config.vcf_sv_research = self.get_file_from_hk(self.case_tags.sv_research_vcf)
         self.include_multiqc_report()
-        self.include_delivery_report()
 
     def include_sample_files(self, config_sample: ScoutMipIndividual) -> None:
         """Include sample level files that are optional for mip samples"""
@@ -159,7 +166,7 @@ class MipConfigBuilder(ScoutConfigBuilder):
         )
 
     @staticmethod
-    def extract_generic_filepath(file_path: Optional[str]) -> Optional[str]:
+    def extract_generic_filepath(file_path: str | None) -> str | None:
         """Remove a file's suffix and identifying integer or X/Y
         Example:
         `/some/path/gatkcomb_rhocall_vt_af_chromograph_sites_X.png` becomes
@@ -182,7 +189,7 @@ class MipConfigBuilder(ScoutConfigBuilder):
     def is_multi_sample_case(load_config: ScoutLoadConfig) -> bool:
         return len(load_config.samples) > 1
 
-    def run_madeline(self, family_obj: Family) -> Path:
+    def run_madeline(self, family_obj: Case) -> Path:
         """Generate a madeline file for an analysis. Use customer sample names"""
         samples = [
             {
