@@ -1,8 +1,8 @@
-"""Module for Balsamic Analysis API"""
+"""Module for Balsamic QC Analysis API."""
 
 import logging
 
-from cg.constants import Pipeline
+from cg.constants import Workflow
 from cg.meta.workflow.balsamic import BalsamicAnalysisAPI
 from cg.models.cg_config import CGConfig
 
@@ -16,6 +16,6 @@ class BalsamicQCAnalysisAPI(BalsamicAnalysisAPI):
     def __init__(
         self,
         config: CGConfig,
-        pipeline: Pipeline = Pipeline.BALSAMIC_QC,
+        workflow: Workflow = Workflow.BALSAMIC_QC,
     ):
-        super().__init__(config=config, pipeline=pipeline)
+        super().__init__(config=config, workflow=workflow)
