@@ -1,5 +1,3 @@
-from typing import Dict
-
 from cg.models.analysis import AnalysisModel
 from cg.models.balsamic.config import BalsamicConfigJSON
 from cg.models.balsamic.metrics import BalsamicQCMetrics
@@ -14,4 +12,4 @@ class BalsamicAnalysis(AnalysisModel):
     """
 
     config: BalsamicConfigJSON
-    sample_metrics: Dict[str, BalsamicQCMetrics]
+    sample_metrics: dict[str, BalsamicQCMetrics]
