@@ -13,7 +13,7 @@ class SbatchError(BaseModel):
 class SbatchCommand(BaseModel):
     run_dir: str  # path/to/a_flowcell/
     demux_dir: str  # path/to/output_dir/
-    unaligned_dir: str  # path/to/output_dir/Unaligned/
+    unaligned_dir: str | None = None  # path/to/output_dir/Unaligned/
     sample_sheet: str  # path/to/SampleSheet.csv
     demux_completed_file: str  # path/to/demuxcomplete.txt
     environment: Literal["stage", "production"]
