@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import List, Optional, Callable
+from typing import Callable
 
 from sqlalchemy.orm import Query
 
@@ -23,15 +23,15 @@ def filter_customer_by_exclude_customer_internal_id(
 class CustomerFilter(Enum):
     """Define customer filter functions."""
 
-    FILTER_BY_INTERNAL_ID: Callable = filter_customer_by_customer_internal_id
+    BY_INTERNAL_ID: Callable = filter_customer_by_customer_internal_id
     EXCLUDE_INTERNAL_ID: Callable = filter_customer_by_exclude_customer_internal_id
 
 
 def apply_customer_filter(
     customers: Query,
-    filter_functions: List[Callable],
-    customer_internal_id: Optional[str] = None,
-    exclude_customer_internal_id: Optional[str] = None,
+    filter_functions: list[Callable],
+    customer_internal_id: str | None = None,
+    exclude_customer_internal_id: str | None = None,
 ) -> Query:
     """Apply filtering functions and return filtered results."""
     for filter_function in filter_functions:
