@@ -5,12 +5,12 @@
 import pytest
 
 from cg.constants.constants import FileFormat
-from cg.constants.subject import Gender
+from cg.constants.subject import Sex
 from cg.io.controller import WriteStream
 
 
-@pytest.fixture(name="genotype_export_sample_output")
-def fixture_genotype_export_sample_output(genotype_config: dict) -> str:
+@pytest.fixture
+def genotype_export_sample_output(genotype_config: dict) -> str:
     """
     genotype API fixture
     """
@@ -18,21 +18,21 @@ def fixture_genotype_export_sample_output(genotype_config: dict) -> str:
         "ACC6987A15": {
             "status": None,
             "sample_created_in_genotype_db": "2020-07-15",
-            "sex": Gender.FEMALE,
+            "sex": Sex.FEMALE,
             "comment": None,
         },
         "ACC6987A16": {
             "status": None,
             "sample_created_in_genotype_db": "2020-07-15",
-            "sex": Gender.FEMALE,
+            "sex": Sex.FEMALE,
             "comment": None,
         },
     }
     return WriteStream.write_stream_from_content(content=sample_output, file_format=FileFormat.JSON)
 
 
-@pytest.fixture(name="genotype_export_sample_analysis_output")
-def fixture_genotype_export_sample_analysis_output() -> str:
+@pytest.fixture
+def genotype_export_sample_analysis_output() -> str:
     """Return some output from a sample analysis export"""
     sample_analysis_output = {
         "ACC6987A15": {
