@@ -1,15 +1,15 @@
 """Test how the api handles files."""
+
 from datetime import datetime
 from pathlib import Path
-from typing import List, Dict, Any
+from typing import Any
+
+from housekeeper.store.models import File, Version
 
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.constants import SequencingFileTag
 from tests.meta.compress.conftest import MockCompressionData
 from tests.mocks.hk_mock import MockHousekeeperAPI
-
-from housekeeper.store.models import Version, File
-
 from tests.small_helpers import SmallHelpers
 from tests.store_helpers import StoreHelpers
 
@@ -85,25 +85,7 @@ def test_add_new_file(
     assert new_nr_files == nr_files_in_db + 1
 
 
-def test_get_files(
-    populated_housekeeper_api: MockHousekeeperAPI,
-    case_id: str,
-    tags: List[str],
-    small_helpers: SmallHelpers,
-):
-    """Test get files method."""
-    # GIVEN a populated housekeeper api with some files
-    nr_files = small_helpers.length_of_iterable(populated_housekeeper_api.files())
-    assert nr_files > 0
-
-    # WHEN fetching all files
-    files = populated_housekeeper_api.get_files(bundle=case_id, tags=tags)
-
-    # THEN assert all files where fetched
-    assert small_helpers.length_of_iterable(files) == nr_files
-
-
-def test_get_file(populated_housekeeper_api: MockHousekeeperAPI):
+def test_get_file(populated_housekeeper_api: HousekeeperAPI):
     """Test to get a file from the database."""
     # GIVEN a housekeeper api with a file
     hk_file: File = populated_housekeeper_api.files().first()
@@ -121,7 +103,7 @@ def test_get_file(populated_housekeeper_api: MockHousekeeperAPI):
 def test_get_files_from_version(
     helpers: StoreHelpers,
     real_housekeeper_api: HousekeeperAPI,
-    hk_bundle_data: Dict[str, Any],
+    hk_bundle_data: dict[str, Any],
     hk_tag: str,
     observations_clinical_snv_file_path: Path,
     observations_clinical_sv_file_path: Path,
@@ -142,7 +124,7 @@ def test_get_files_from_version(
     assert second_file in version.files
 
     # WHEN extracting the files from version
-    files: List[File] = real_housekeeper_api.get_files_from_version(version=version, tags={hk_tag})
+    files: list[File] = real_housekeeper_api.get_files_from_version(version=version, tags={hk_tag})
 
     # THEN the added files should be retrieved
     assert first_file in files
@@ -152,7 +134,7 @@ def test_get_files_from_version(
 def test_get_latest_file_from_version(
     helpers: StoreHelpers,
     real_housekeeper_api: HousekeeperAPI,
-    hk_bundle_data: Dict[str, Any],
+    hk_bundle_data: dict[str, Any],
     hk_tag: str,
     observations_clinical_snv_file_path: Path,
     observations_clinical_sv_file_path: Path,
@@ -181,7 +163,7 @@ def test_get_latest_file_from_version(
     assert latest_file == second_file
 
 
-def test_get_file_from_latest_version(case_id: str, populated_housekeeper_api: MockHousekeeperAPI):
+def test_get_file_from_latest_version(case_id: str, populated_housekeeper_api: HousekeeperAPI):
     """Test to get a file from the database from the latest version."""
     # GIVEN a housekeeper api with a file
     hk_file: File = populated_housekeeper_api.files().first()
@@ -199,7 +181,7 @@ def test_get_file_from_latest_version(case_id: str, populated_housekeeper_api: M
 
 
 def test_get_files_from_latest_version(
-    case_id: str, populated_housekeeper_api: MockHousekeeperAPI, small_helpers: SmallHelpers
+    case_id: str, populated_housekeeper_api: HousekeeperAPI, small_helpers: SmallHelpers
 ):
     """Test to get files from the database from the latest version."""
 
@@ -218,7 +200,7 @@ def test_get_files_from_latest_version(
     )
 
     # WHEN fetching the files
-    hk_files: List[File] = populated_housekeeper_api.get_files_from_latest_version(
+    hk_files: list[File] = populated_housekeeper_api.get_files_from_latest_version(
         bundle_name=case_id, tags=[hk_file.tags[0].name]
     )
 
@@ -241,7 +223,7 @@ def test_delete_file(populated_housekeeper_api: HousekeeperAPI):
     assert populated_housekeeper_api.get_file(hk_file.id) is None
 
 
-def test_get_included_path(populated_housekeeper_api: MockHousekeeperAPI, case_id: str):
+def test_get_included_path(populated_housekeeper_api: HousekeeperAPI, case_id: str):
     """Test to get the included path for a file."""
     # GIVEN a populated housekeeper api and the root dir
     root_dir: Path = Path(populated_housekeeper_api.get_root_dir())
@@ -262,7 +244,7 @@ def test_get_included_path(populated_housekeeper_api: MockHousekeeperAPI, case_i
     assert included_path == Path(root_dir, version.relative_root_dir, Path(hk_file.path).name)
 
 
-def test_get_include_file(populated_housekeeper_api: MockHousekeeperAPI, case_id: str):
+def test_get_include_file(populated_housekeeper_api: HousekeeperAPI, case_id: str):
     """Test to get the included path for a file."""
     # GIVEN a populated housekeeper api and the root dir
     root_dir: Path = Path(populated_housekeeper_api.get_root_dir())
@@ -285,7 +267,7 @@ def test_get_include_file(populated_housekeeper_api: MockHousekeeperAPI, case_id
 
 
 def test_include_files_to_latest_version_when_included(
-    caplog, case_id: str, populated_housekeeper_api: MockHousekeeperAPI
+    caplog, case_id: str, populated_housekeeper_api: HousekeeperAPI
 ):
     """Test to include files for a bundle."""
     # GIVEN a populated Housekeeper API and the root dir
@@ -320,7 +302,7 @@ def test_include_files_to_latest_version(
     case_id: str,
     madeline_output: Path,
     not_existing_hk_tag: str,
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
 ):
     """Test to include files for a bundle."""
     # GIVEN a populated Housekeeper API and the root dir
@@ -356,8 +338,8 @@ def test_include_files_to_latest_version(
 
 def test_check_bundle_files(
     case_id: str,
-    timestamp: datetime,
-    populated_housekeeper_api: MockHousekeeperAPI,
+    timestamp_yesterday: datetime,
+    populated_housekeeper_api: HousekeeperAPI,
     hk_version: Version,
     fastq_file: Path,
     sample_id: str,
@@ -365,10 +347,10 @@ def test_check_bundle_files(
 ):
     """Test to see if the function correctly identifies a file that is present and returns a lis without it."""
     # GIVEN a housekeeper version with a file
-    version: Version = populated_housekeeper_api.version(bundle=case_id, date=timestamp)
+    version: Version = populated_housekeeper_api.version(bundle=case_id, date=timestamp_yesterday)
 
     # WHEN attempting to add two files, one existing and one new
-    files_to_add: List[Path] = populated_housekeeper_api.check_bundle_files(
+    files_to_add: list[Path] = populated_housekeeper_api.check_bundle_files(
         file_paths=[bed_file, fastq_file],
         bundle_name=case_id,
         last_version=version,
@@ -378,7 +360,7 @@ def test_check_bundle_files(
     assert files_to_add == [fastq_file]
 
 
-def test_get_tag_names_from_file(populated_housekeeper_api: MockHousekeeperAPI):
+def test_get_tag_names_from_file(populated_housekeeper_api: HousekeeperAPI):
     """Test get tag names on a file."""
     # GIVEN a housekeeper api with a file
     hk_file = populated_housekeeper_api.files().first()
@@ -396,9 +378,9 @@ def test_get_tag_names_from_file(populated_housekeeper_api: MockHousekeeperAPI):
 
 
 def test_is_fastq_or_spring_in_all_bundles_when_none(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
-    tags: List[str],
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are present in bundles when no files are present."""
     # GIVEN a populated housekeeper api with some files
@@ -411,10 +393,10 @@ def test_is_fastq_or_spring_in_all_bundles_when_none(
 
 
 def test_is_fastq_or_spring_in_all_bundles(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
     madeline_output: Path,
-    tags: List[str],
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are present in bundles when files are present."""
     # GIVEN a populated housekeeper api with some files
@@ -432,11 +414,11 @@ def test_is_fastq_or_spring_in_all_bundles(
 
 
 def test_is_fastq_or_spring_in_all_bundles_when_missing(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
-    sample_id: str,
     madeline_output: Path,
-    tags: List[str],
+    new_bundle_name: str,
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are present in bundles when not all bundles have files present."""
     # GIVEN a populated housekeeper api with some files
@@ -448,13 +430,13 @@ def test_is_fastq_or_spring_in_all_bundles_when_missing(
     )
 
     # GIVEN an empty bundle
-    populated_housekeeper_api.create_new_bundle_and_version(name=sample_id)
+    populated_housekeeper_api.create_new_bundle_and_version(name=new_bundle_name)
 
     populated_housekeeper_api.commit()
 
     # WHEN fetching all files
     was_true = populated_housekeeper_api.is_fastq_or_spring_in_all_bundles(
-        bundle_names=[case_id, sample_id]
+        bundle_names=[case_id, new_bundle_name]
     )
 
     # THEN assert all file were not present in all bundles
@@ -464,10 +446,10 @@ def test_is_fastq_or_spring_in_all_bundles_when_missing(
 def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles(
     case_id: str,
     compression_object: MockCompressionData,
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     madeline_output: Path,
-    sample_id: str,
-    tags: List[str],
+    new_bundle_name: str,
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are present in bundles when all bundles have files present."""
     # GIVEN a populated housekeeper api with some files
@@ -478,7 +460,7 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles(
     )
 
     # GIVEN an empty bundle
-    populated_housekeeper_api.create_new_bundle_and_version(name=sample_id)
+    populated_housekeeper_api.create_new_bundle_and_version(name=new_bundle_name)
 
     # GIVEN an existing SPRING metadata file
     compression_object.spring_metadata_path.touch()
@@ -486,13 +468,13 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles(
     # GIVEN a SPRING file tag with a file included the bundle
     populated_housekeeper_api.add_and_include_file_to_latest_version(
         file=compression_object.spring_metadata_path,
-        bundle_name=sample_id,
+        bundle_name=new_bundle_name,
         tags=[SequencingFileTag.SPRING_METADATA],
     )
 
     # WHEN fetching all files
     was_true = populated_housekeeper_api.is_fastq_or_spring_in_all_bundles(
-        bundle_names=[case_id, sample_id]
+        bundle_names=[case_id, new_bundle_name]
     )
 
     # THEN assert all file were present in all bundles
@@ -502,10 +484,10 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles(
 def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles_and_files(
     case_id: str,
     compression_object: MockCompressionData,
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     madeline_output: Path,
-    sample_id: str,
-    tags: List[str],
+    new_bundle_name: str,
+    tags: list[str],
 ):
     """
     Test checking if all FASTQ or SPRING files are present in bundles when all bundles have files present and some
@@ -519,7 +501,7 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles_and_files(
     )
 
     # GIVEN an empty bundle
-    populated_housekeeper_api.create_new_bundle_and_version(name=sample_id)
+    populated_housekeeper_api.create_new_bundle_and_version(name=new_bundle_name)
 
     # GIVEN an existing SPRING metadata file
     compression_object.spring_metadata_path.touch()
@@ -527,13 +509,13 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles_and_files(
     # GIVEN a SPRING file tag with a file included in the bundle
     populated_housekeeper_api.add_and_include_file_to_latest_version(
         file=compression_object.spring_metadata_path,
-        bundle_name=sample_id,
+        bundle_name=new_bundle_name,
         tags=[SequencingFileTag.SPRING_METADATA],
     )
 
     # WHEN fetching all files
     was_true = populated_housekeeper_api.is_fastq_or_spring_in_all_bundles(
-        bundle_names=[case_id, sample_id]
+        bundle_names=[case_id, new_bundle_name]
     )
 
     # THEN assert all file were present in all bundles
@@ -541,9 +523,9 @@ def test_is_fastq_or_spring_in_all_bundles_when_multiple_bundles_and_files(
 
 
 def test_is_fastq_or_spring_on_disk_in_all_bundles_when_none(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
-    tags: List[str],
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are on disk in bundles when no files are on disk."""
     # GIVEN a populated housekeeper api with some files
@@ -558,10 +540,10 @@ def test_is_fastq_or_spring_on_disk_in_all_bundles_when_none(
 
 
 def test_is_fastq_or_spring_on_disk_in_all_bundles(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
     madeline_output: Path,
-    tags: List[str],
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are on disk in bundles when files are on disk."""
     # GIVEN a populated housekeeper api with some files
@@ -581,11 +563,12 @@ def test_is_fastq_or_spring_on_disk_in_all_bundles(
 
 
 def test_is_fastq_or_spring_on_disk_in_all_bundles_when_missing_file(
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     case_id: str,
     sample_id: str,
     madeline_output: Path,
-    tags: List[str],
+    new_bundle_name: str,
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are on disk in bundles when not all bundles have files on disk."""
     # GIVEN a populated housekeeper api with some files
@@ -597,7 +580,7 @@ def test_is_fastq_or_spring_on_disk_in_all_bundles_when_missing_file(
     )
 
     # GIVEN an empty bundle
-    populated_housekeeper_api.create_new_bundle_and_version(name=sample_id)
+    populated_housekeeper_api.create_new_bundle_and_version(name=new_bundle_name)
 
     # GIVEN a FASTQ file tag in the bundle, but not on disk
     populated_housekeeper_api.add_file(
@@ -608,7 +591,7 @@ def test_is_fastq_or_spring_on_disk_in_all_bundles_when_missing_file(
 
     # WHEN fetching all files
     was_true = populated_housekeeper_api.is_fastq_or_spring_on_disk_in_all_bundles(
-        bundle_names=[case_id, sample_id]
+        bundle_names=[case_id, new_bundle_name]
     )
 
     # THEN assert all file were not on disk in all bundles
@@ -618,10 +601,10 @@ def test_is_fastq_or_spring_on_disk_in_all_bundles_when_missing_file(
 def testis_fastq_or_spring_on_disk_in_all_bundles_when_multiple_bundles(
     case_id: str,
     compression_object: MockCompressionData,
-    populated_housekeeper_api: MockHousekeeperAPI,
+    populated_housekeeper_api: HousekeeperAPI,
     madeline_output: Path,
-    sample_id: str,
-    tags: List[str],
+    new_bundle_name: str,
+    tags: list[str],
 ):
     """Test checking if all FASTQ or SPRING files are on disk in bundles when all bundles have files on disk."""
     # GIVEN a populated housekeeper api with some files
@@ -632,7 +615,7 @@ def testis_fastq_or_spring_on_disk_in_all_bundles_when_multiple_bundles(
     )
 
     # GIVEN an empty bundle
-    populated_housekeeper_api.create_new_bundle_and_version(name=sample_id)
+    populated_housekeeper_api.create_new_bundle_and_version(name=new_bundle_name)
 
     # GIVEN an existing SPRING metadata file
     compression_object.spring_metadata_path.touch()
@@ -640,14 +623,203 @@ def testis_fastq_or_spring_on_disk_in_all_bundles_when_multiple_bundles(
     # GIVEN a SPRING file tag with a file included the bundle
     populated_housekeeper_api.add_and_include_file_to_latest_version(
         file=compression_object.spring_metadata_path,
-        bundle_name=sample_id,
+        bundle_name=new_bundle_name,
         tags=[SequencingFileTag.SPRING_METADATA],
     )
 
     # WHEN fetching all files
     was_true = populated_housekeeper_api.is_fastq_or_spring_on_disk_in_all_bundles(
-        bundle_names=[case_id, sample_id]
+        bundle_names=[case_id, new_bundle_name]
     )
 
     # THEN assert all file were on disk in all bundles
     assert was_true
+
+
+def test_get_non_archived_spring_path_and_bundle_name(populated_housekeeper_api: HousekeeperAPI):
+    """Test fetching the path and associated bundle for each non-archived SPRING file."""
+    # GIVEN a housekeeper_api containing spring_files which are not archived
+
+    # WHEN fetching all non-archived spring baths and bundle names
+    files_and_bundle_names: list[tuple[str, str]] = (
+        populated_housekeeper_api.get_non_archived_spring_path_and_bundle_name()
+    )
+    assert len(files_and_bundle_names) > 0
+    # THEN each file should be a spring file
+    # THEN none of the files should have an archive
+    # THEN each of the files should have a corresponding bundle name
+    for bundle_name, file in files_and_bundle_names:
+        housekeeper_file: File = populated_housekeeper_api.files(path=file).first()
+        assert SequencingFileTag.SPRING in [tag.name for tag in housekeeper_file.tags]
+        assert not housekeeper_file.archive
+        assert bundle_name == housekeeper_file.version.bundle.name
+
+
+def test_get_file_insensitive_path(bed_file: Path, populated_housekeeper_api: HousekeeperAPI):
+    """Test that a file is fetched given its path."""
+    # GIVEN the path of a file in Housekeeper API
+
+    # WHEN getting the file though the path
+    file: File = populated_housekeeper_api.get_file_insensitive_path(path=bed_file)
+
+    # THEN the file is fetched correctly
+    assert file
+
+
+def test_get_files_containing_tags(
+    populated_housekeeper_api: HousekeeperAPI, sample_id: str, fastq_file: Path, spring_file: Path
+):
+    """Test get files containing specific tags."""
+
+    # GIVEN a populated Housekeeper API and a list of sample files
+    files: list[File] = populated_housekeeper_api.get_files_from_latest_version(sample_id)
+    files_names: list[str] = [Path(file.full_path).name for file in files]
+    assert spring_file.name in files_names
+    assert fastq_file.name in files_names
+
+    # GIVEN a list of fastq file tags
+    tags: list[set[str]] = [{SequencingFileTag.FASTQ}]
+
+    # WHEN getting a list of files with tags
+    filtered_files: list[File] = populated_housekeeper_api.get_files_containing_tags(
+        files=files, tags=tags
+    )
+
+    # THEN only the expected fastq sample files should be retrieved
+    filtered_files_names: list[str] = [Path(file.full_path).name for file in filtered_files]
+    assert fastq_file.name in filtered_files_names
+    assert spring_file.name not in filtered_files_names
+
+
+def test_get_files_when_using_no_tags(
+    populated_housekeeper_api: HousekeeperAPI, sample_id: str, empty_list: list
+):
+    """Test get files containing an empty list of tags."""
+
+    # GIVEN a populated Housekeeper API and a list of sample files
+    files: list[File] = populated_housekeeper_api.get_files_from_latest_version(sample_id)
+
+    # WHEN getting a list of files providing an empty list of tags
+    filtered_files: list[File] = populated_housekeeper_api.get_files_containing_tags(
+        files=files, tags=empty_list
+    )
+
+    # THEN an empty list should be returned
+    assert filtered_files == empty_list
+
+
+def test_filter_files_without_tags(
+    populated_housekeeper_api: HousekeeperAPI, sample_id: str, fastq_file: Path, spring_file: Path
+):
+    """Test get files without specific tags."""
+
+    # GIVEN a populated Housekeeper API and a list of sample files
+    files: list[File] = populated_housekeeper_api.get_files_from_latest_version(sample_id)
+    files_names: list[str] = [Path(file.full_path).name for file in files]
+    assert spring_file.name in files_names
+    assert fastq_file.name in files_names
+
+    # GIVEN a list of fastq file tags to exclude
+    excluded_tags: list[str] = [SequencingFileTag.FASTQ]
+
+    # WHEN getting a list of files lacking excluded tags
+    filtered_files: list[File] = populated_housekeeper_api.get_files_without_excluded_tags(
+        files=files, excluded_tags=excluded_tags
+    )
+
+    # THEN only the expected sample spring files should be retrieved
+    filtered_files_names: list[str] = [Path(file.full_path).name for file in filtered_files]
+    assert spring_file.name in filtered_files_names
+    assert fastq_file.name not in filtered_files_names
+
+
+def test_get_files_without_excluded_tags_using_no_tags(
+    populated_housekeeper_api: HousekeeperAPI,
+    sample_id: str,
+    fastq_file: Path,
+    spring_file: Path,
+    empty_list: list,
+):
+    """Test get files without tags for an empty tag input."""
+
+    # GIVEN a populated Housekeeper API and a list of sample files
+    files: list[File] = populated_housekeeper_api.get_files_from_latest_version(sample_id)
+
+    # WHEN getting a list of files without tags when providing an empty list of tags
+    filtered_files: list[File] = populated_housekeeper_api.get_files_without_excluded_tags(
+        files=files, excluded_tags=empty_list
+    )
+
+    # THEN the complete list of original files should be returned
+    assert filtered_files == files
+
+
+def test_get_files_from_latest_version_containing_tags(
+    populated_housekeeper_api: HousekeeperAPI, sample_id: str, fastq_file: Path, spring_file: Path
+):
+    """Test get files from latest version by tags."""
+
+    # GIVEN a populated Housekeeper API
+
+    # GIVEN a list of fastq file tags
+    tags: list[set[str]] = [{SequencingFileTag.FASTQ}]
+
+    # WHEN getting a list of files that match specific tags
+    filtered_files: list[File] = (
+        populated_housekeeper_api.get_files_from_latest_version_containing_tags(
+            bundle_name=sample_id, tags=tags
+        )
+    )
+
+    # THEN only the expected fastq sample files should be returned
+    filtered_files_names: list[str] = [Path(file.full_path).name for file in filtered_files]
+    assert fastq_file.name in filtered_files_names
+    assert spring_file.name not in filtered_files_names
+
+
+def test_get_files_from_latest_version_using_no_tags(
+    populated_housekeeper_api: HousekeeperAPI,
+    sample_id: str,
+    fastq_file: Path,
+    spring_file: Path,
+    empty_list: list,
+):
+    """Test get files from the latest version by empty list of tags."""
+
+    # GIVEN a populated Housekeeper API
+
+    # WHEN getting a list of files that match empty tags
+    filtered_files: list[File] = (
+        populated_housekeeper_api.get_files_from_latest_version_containing_tags(
+            bundle_name=sample_id, tags=empty_list
+        )
+    )
+
+    # THEN an empty list should be returned
+    assert filtered_files == empty_list
+
+
+def test_get_files_from_latest_version_containing_tags_and_excluded_tags(
+    populated_housekeeper_api: HousekeeperAPI, sample_id: str, fastq_file: Path, spring_file: Path
+):
+    """Test get files from the latest version by tags and excluded tags."""
+
+    # GIVEN a populated Housekeeper API
+
+    # GIVEN a list of sample id tags
+    tags: list[set[str]] = [{sample_id}]
+
+    # GIVEN a list of fastq file tags to exclude
+    excluded_tags: list[str] = [SequencingFileTag.FASTQ]
+
+    # WHEN getting a list of files that match the sample ID tag and exclude the fastq files
+    filtered_files: list[File] = (
+        populated_housekeeper_api.get_files_from_latest_version_containing_tags(
+            bundle_name=sample_id, tags=tags, excluded_tags=excluded_tags
+        )
+    )
+
+    # THEN only the expected fastq sample files should be returned
+    filtered_files_names: list[str] = [Path(file.full_path).name for file in filtered_files]
+    assert spring_file.name in filtered_files_names
+    assert fastq_file.name not in filtered_files_names
