@@ -1,22 +1,21 @@
 """Fixtures for testing the madeline cg app"""
 
 from pathlib import Path
-from typing import Dict, List, Optional
 
 import pytest
-from tests.mocks.process_mock import ProcessMock
 
 from cg.apps.madeline.api import MadelineAPI
+from tests.mocks.process_mock import ProcessMock
 
 
-@pytest.fixture(name="madeline_output")
-def fixture_madeline_output(apps_dir: Path) -> Path:
+@pytest.fixture
+def madeline_output(apps_dir: Path) -> Path:
     """Path to madeline output"""
     return apps_dir / "madeline" / "madeline.xml"
 
 
-@pytest.fixture(name="madeline_columns")
-def fixture_madeline_columns() -> Dict[str, str]:
+@pytest.fixture
+def madeline_columns() -> dict[str, str]:
     """return a dictionary with madeline columns"""
     columns = {
         "case": "FamilyId",
@@ -31,8 +30,8 @@ def fixture_madeline_columns() -> Dict[str, str]:
     return columns
 
 
-@pytest.fixture(name="mother")
-def fixture_mother() -> Dict[str, Optional[str]]:
+@pytest.fixture
+def mother() -> dict[str, str | None]:
     """return a dictionary with ind info"""
     ind_info = {
         "sample": "mother",
@@ -43,8 +42,8 @@ def fixture_mother() -> Dict[str, Optional[str]]:
     return ind_info
 
 
-@pytest.fixture(name="father")
-def fixture_father() -> Dict[str, Optional[str]]:
+@pytest.fixture
+def father() -> dict[str, str | None]:
     """return a dictionary with ind info"""
     ind_info = {
         "sample": "father",
@@ -55,8 +54,8 @@ def fixture_father() -> Dict[str, Optional[str]]:
     return ind_info
 
 
-@pytest.fixture(name="proband")
-def fixture_proband() -> Dict[str, Optional[str]]:
+@pytest.fixture
+def proband() -> dict[str, str | None]:
     """return a dictionary with ind info"""
     ind_info = {
         "sample": "proband",
@@ -70,14 +69,14 @@ def fixture_proband() -> Dict[str, Optional[str]]:
     return ind_info
 
 
-@pytest.fixture(name="trio")
-def fixture_trio(proband: dict, mother: dict, father: dict) -> List[Dict[str, Optional[str]]]:
+@pytest.fixture
+def trio(proband: dict, mother: dict, father: dict) -> list[dict[str, str | None]]:
     """return a list with a trio"""
     return [proband, mother, father]
 
 
-@pytest.fixture(name="madeline_api")
-def fixture_madeline_api() -> MadelineAPI:
+@pytest.fixture
+def madeline_api() -> MadelineAPI:
     """Return a madeline API with mocked process"""
     binary_path = "madeline"
     config = {"madeline_exe": binary_path}
@@ -87,8 +86,8 @@ def fixture_madeline_api() -> MadelineAPI:
     return madeline_api
 
 
-@pytest.fixture(name="populated_madeline_api")
-def fixture_populated_madeline_api(madeline_output: Path, madeline_api: MadelineAPI) -> MadelineAPI:
+@pytest.fixture
+def populated_madeline_api(madeline_output: Path, madeline_api: MadelineAPI) -> MadelineAPI:
     """Return a madeline API populated with some output"""
     with open(madeline_output, "r") as output:
         madeline_content = output.read()
