@@ -1,13 +1,15 @@
 """Fixtures for testing mip app"""
 
 import pytest
-from typing import List
+
+from cg.constants import FileExtensions
+from cg.constants.subject import Sex
 
 
 def create_file(tmpdir, flowcell, lane, read, file_content):
     """actual file on disk"""
 
-    file_name = f"S1_FC000{flowcell}_L00{lane}_R_{read}.fastq.gz"
+    file_name = f"S1_FC000{flowcell}_L00{lane}_R_{read}{FileExtensions.FASTQ}{FileExtensions.GZIP}"
     file_path = tmpdir / file_name
     file_path.write(file_content)
     return file_path
@@ -30,7 +32,7 @@ class MockTB:
     def __init__(self):
         self._link_was_called = False
 
-    def link(self, family: str, sample: str, analysis_type: str, files: List[dict]):
+    def link(self, family: str, sample: str, analysis_type: str, files: list[dict]):
         """Link files mock"""
 
         del family, sample, analysis_type, files
@@ -50,7 +52,7 @@ def valid_config():
         father="0",
         mother="0",
         phenotype="affected",
-        sex="male",
+        sex=Sex.MALE,
         expected_coverage=15,
         capture_kit="agilent_sureselect_cre.v1",
     )
@@ -69,7 +71,7 @@ def invalid_config_analysis_type():
         father="0",
         mother="0",
         phenotype="affected",
-        sex="male",
+        sex=Sex.MALE,
         expected_coverage=15,
         capture_kit="agilent_sureselect_cre.v1",
     )
@@ -90,7 +92,7 @@ def invalid_config_unknown_field():
         father="0",
         mother="0",
         phenotype="affected",
-        sex="male",
+        sex=Sex.MALE,
         expected_coverage=15,
         capture_kit="agilent_sureselect_cre.v1",
         unknown_field="UNKNOWN",
@@ -111,7 +113,7 @@ def invalid_config_unknown_field_sample_id():
         father="0",
         mother="0",
         phenotype="affected",
-        sex="male",
+        sex=Sex.MALE,
         expected_coverage=15,
         capture_kit="agilent_sureselect_cre.v1",
     )
@@ -132,7 +134,7 @@ def invalid_config_unknown_field_analysis_type():
         father="0",
         mother="0",
         phenotype="affected",
-        sex="male",
+        sex=Sex.MALE,
         expected_coverage=15,
         capture_kit="agilent_sureselect_cre.v1",
     )
