@@ -1,10 +1,10 @@
+from click.testing import CliRunner
+
 from cg.cli.add import add
 from cg.constants import EXIT_SUCCESS
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from click.testing import CliRunner
-
 from cg.store.models import User
+from cg.store.store import Store
 
 
 def test_add_user(cli_runner: CliRunner, base_context: CGConfig):
