@@ -1,30 +1,30 @@
-"""Fixtures for cli clean tests"""
+"""Fixtures for cli clean tests."""
 
 import datetime
 from pathlib import Path
 
 import pytest
 
-from cg.constants import Pipeline
+from cg.constants import Workflow
 from cg.meta.workflow.balsamic import BalsamicAnalysisAPI
 from cg.meta.workflow.microsalt import MicrosaltAnalysisAPI
 from cg.models.cg_config import CGConfig
 from tests.store_helpers import StoreHelpers
 
 
-@pytest.fixture(name="balsamic_case_clean")
-def fixture_balsamic_case_clean() -> str:
+@pytest.fixture
+def balsamic_case_clean() -> str:
     """Return a balsamic case to clean"""
     return "balsamic_case_clean"
 
 
-@pytest.fixture(name="balsamic_case_not_clean")
-def fixture_balsamic_case_not_clean() -> str:
+@pytest.fixture
+def balsamic_case_not_clean() -> str:
     """Return a balsamic case to clean"""
     return "balsamic_case_not_clean"
 
 
-@pytest.fixture()
+@pytest.fixture
 def clean_context(
     balsamic_case_clean: str,
     balsamic_case_not_clean: str,
@@ -41,23 +41,20 @@ def clean_context(
         store=store,
         internal_id=balsamic_case_clean,
         name=balsamic_case_clean,
-        data_analysis=Pipeline.BALSAMIC,
+        data_analysis=Workflow.BALSAMIC,
     )
     sample_case_to_clean = helpers.add_sample(
-        store,
-        internal_id=balsamic_case_clean,
-        is_tumour=True,
-        application_type="wgs",
+        store, application_type="wgs", is_tumour=True, internal_id=balsamic_case_clean
     )
     helpers.add_relationship(store, case=case_to_clean, sample=sample_case_to_clean)
 
     helpers.add_analysis(
         store,
         case=case_to_clean,
-        pipeline=Pipeline.BALSAMIC,
         started_at=timestamp_yesterday,
         uploaded_at=timestamp_yesterday,
         cleaned_at=None,
+        workflow=Workflow.BALSAMIC,
     )
     Path(analysis_api.get_case_path(balsamic_case_clean)).mkdir(exist_ok=True, parents=True)
 
@@ -66,26 +63,23 @@ def clean_context(
         store=store,
         internal_id=balsamic_case_not_clean,
         name=balsamic_case_not_clean,
-        data_analysis=Pipeline.BALSAMIC,
+        data_analysis=Workflow.BALSAMIC,
     )
     case_to_not_clean.action = "running"
     store.session.commit()
 
     sample_case_to_not_clean = helpers.add_sample(
-        store,
-        internal_id=balsamic_case_not_clean,
-        is_tumour=True,
-        application_type="wgs",
+        store, application_type="wgs", is_tumour=True, internal_id=balsamic_case_not_clean
     )
     helpers.add_relationship(store, case=case_to_not_clean, sample=sample_case_to_not_clean)
 
     helpers.add_analysis(
         store,
         case=case_to_not_clean,
-        pipeline=Pipeline.BALSAMIC,
         started_at=timestamp_yesterday,
         uploaded_at=timestamp_yesterday,
         cleaned_at=None,
+        workflow=Workflow.BALSAMIC,
     )
     Path(analysis_api.get_case_path(balsamic_case_not_clean)).mkdir(exist_ok=True, parents=True)
     cg_context.meta_apis["analysis_api"] = analysis_api
@@ -95,9 +89,9 @@ def clean_context(
     return cg_context
 
 
-@pytest.fixture(name="rsync_process")
-def fixture_rsync_process(project_dir: Path) -> Path:
-    """Return a rsync process after ensuing that is is created"""
+@pytest.fixture
+def rsync_process(project_dir: Path) -> Path:
+    """Return a rsync process after ensuing that is created"""
 
     rsync_process = project_dir / "rsync" / "rsync_process"
 
@@ -105,14 +99,14 @@ def fixture_rsync_process(project_dir: Path) -> Path:
     return rsync_process
 
 
-@pytest.fixture(name="microsalt_case_clean_dry")
-def fixture_microsalt_case_clean_dry() -> str:
+@pytest.fixture
+def microsalt_case_clean_dry() -> str:
     """Return a microsalt case to clean in dry-run"""
     return "microsalt_case_clean_dry"
 
 
-@pytest.fixture(name="microsalt_case_clean")
-def fixture_microsalt_case_not_clean() -> str:
+@pytest.fixture
+def microsalt_case_clean() -> str:
     """Return a microsalt case to clean"""
     return "microsalt_case_clean"
 
@@ -137,29 +131,26 @@ def clean_context_microsalt(
 
     # Create textbook case for cleaning
     MicrosaltAnalysisAPI.get_case_path.return_value = [
-        Path("home/proj/production/microbial/test/result", microsalt_case_clean)
+        Path(analysis_api.root_dir, microsalt_case_clean)
     ]
 
     case_to_clean = helpers.add_case(
         store=store,
         internal_id=microsalt_case_clean,
         name=microsalt_case_clean,
-        data_analysis=Pipeline.MICROSALT,
-    )
-    sample_case_to_clean = helpers.add_sample(
-        store,
-        internal_id=microsalt_case_clean,
+        data_analysis=Workflow.MICROSALT,
     )
+    sample_case_to_clean = helpers.add_sample(store, internal_id=microsalt_case_clean)
 
     helpers.add_relationship(store, case=case_to_clean, sample=sample_case_to_clean)
 
     helpers.add_analysis(
         store,
         case=case_to_clean,
-        pipeline=Pipeline.MICROSALT,
         started_at=timestamp_yesterday,
         uploaded_at=timestamp_yesterday,
         cleaned_at=None,
+        workflow=Workflow.MICROSALT,
     )
     case_path_list = analysis_api.get_case_path(microsalt_case_clean)
     for path in case_path_list:
@@ -167,29 +158,26 @@ def clean_context_microsalt(
 
     # Create textbook case for cleaning in dry run
     MicrosaltAnalysisAPI.get_case_path.return_value = [
-        Path("home/proj/production/microbial/test/result", microsalt_case_clean_dry)
+        Path(analysis_api.root_dir, microsalt_case_clean_dry)
     ]
 
     case_to_clean_dry_run = helpers.add_case(
         store=store,
         internal_id=microsalt_case_clean_dry,
         name=microsalt_case_clean_dry,
-        data_analysis=Pipeline.MICROSALT,
+        data_analysis=Workflow.MICROSALT,
     )
 
-    sample_case_to_not_clean = helpers.add_sample(
-        store,
-        internal_id=microsalt_case_clean_dry,
-    )
+    sample_case_to_not_clean = helpers.add_sample(store, internal_id=microsalt_case_clean_dry)
     helpers.add_relationship(store, case=case_to_clean_dry_run, sample=sample_case_to_not_clean)
 
     helpers.add_analysis(
         store,
         case=case_to_clean_dry_run,
-        pipeline=Pipeline.MICROSALT,
         started_at=timestamp_yesterday,
         uploaded_at=timestamp_yesterday,
         cleaned_at=None,
+        workflow=Workflow.MICROSALT,
     )
 
     case_path_list = analysis_api.get_case_path(microsalt_case_clean_dry)
