@@ -1,13 +1,14 @@
 """This script tests the cli method to clean old balsamic run dirs"""
+
 import datetime as dt
 import logging
 from pathlib import Path
 
-from cg.apps.tb import TrailblazerAPI
-from cg.cli.workflow.commands import clean_run_dir, past_run_dirs
-from cg.constants import Pipeline
 from click.testing import CliRunner
 
+from cg.apps.tb import TrailblazerAPI
+from cg.cli.workflow.commands import clean_run_dir, past_run_dirs
+from cg.constants import Workflow
 from cg.models.cg_config import CGConfig
 from tests.store_helpers import StoreHelpers
 
@@ -81,10 +82,10 @@ def test_dry_run(
     base_store = clean_context.status_db
     helpers.add_analysis(
         base_store,
-        pipeline=Pipeline.BALSAMIC,
         started_at=timestamp_yesterday,
         uploaded_at=timestamp_yesterday,
         cleaned_at=None,
+        workflow=Workflow.BALSAMIC,
     )
 
     analysis_to_clean = base_store.get_case_by_internal_id(balsamic_case_clean).analyses[0]
@@ -95,12 +96,14 @@ def test_dry_run(
     TrailblazerAPI.is_latest_analysis_ongoing.return_value = False
 
     # WHEN dry running with dry run specified
-    result = cli_runner.invoke(clean_run_dir, [balsamic_case_clean, "-d", "-y"], obj=clean_context)
+    result = cli_runner.invoke(
+        clean_run_dir, [balsamic_case_clean, "--dry-run", "-y"], obj=clean_context
+    )
     # THEN command should say it would have deleted
     assert result.exit_code == EXIT_SUCCESS
     assert "Would have deleted" in caplog.text
     assert balsamic_case_clean in caplog.text
-    assert analysis_to_clean in base_store.get_analyses_to_clean(pipeline=Pipeline.BALSAMIC)
+    assert analysis_to_clean in base_store.get_analyses_to_clean(workflow=Workflow.BALSAMIC)
 
 
 def test_cleaned_at_valid(
@@ -135,7 +138,7 @@ def test_cleaned_at_invalid(
     assert not base_store.get_case_by_internal_id(balsamic_case_not_clean).analyses[0].cleaned_at
     # WHEN dry running with dry run specified
 
-    result = cli_runner.invoke(past_run_dirs, ["2020-12-01", "-d", "-y"], obj=clean_context)
+    result = cli_runner.invoke(past_run_dirs, ["2020-12-01", "--dry-run", "-y"], obj=clean_context)
 
     # THEN case directory should not have been cleaned
     assert result.exit_code == EXIT_SUCCESS
