@@ -2,12 +2,11 @@
 
 import logging
 
-from cg.cli.compress.fastq import (
-    decompress_case,
-)
-from cg.models.cg_config import CGConfig
 from click.testing import CliRunner
 
+from cg.cli.compress.fastq import decompress_case
+from cg.models.cg_config import CGConfig
+
 
 def test_decompress_spring_cli_no_family(
     compress_context: CGConfig, case_id: str, cli_runner: CliRunner, caplog
