@@ -1,38 +1,36 @@
 """Fixtures for deliver commands"""
 
 from pathlib import Path
-from typing import List
 
 import pytest
+from housekeeper.store.models import Version
+
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.constants.delivery import INBOX_NAME
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from housekeeper.store.models import Version
+from cg.store.store import Store
 from tests.store_helpers import StoreHelpers
 
 # Paths
 
 
-@pytest.fixture(name="delivery_inbox")
-def fixture_delivery_inbox(project_dir: Path, customer_id: Path, ticket_id: str) -> Path:
+@pytest.fixture
+def delivery_inbox(project_dir: Path, customer_id: Path, ticket_id: str) -> Path:
     return Path(project_dir, customer_id, INBOX_NAME, ticket_id)
 
 
-@pytest.fixture(name="deliver_vcf_path")
-def fixture_deliver_vcf_path(
-    delivery_inbox: Path, family_name: str, case_id: str, vcf_file: Path
-) -> Path:
+@pytest.fixture
+def deliver_vcf_path(delivery_inbox: Path, family_name: str, case_id: str, vcf_file: Path) -> Path:
     return Path(delivery_inbox, family_name, vcf_file.name.replace(case_id, family_name))
 
 
-@pytest.fixture(name="deliver_fastq_path")
-def fixture_deliver_fastq_path(delivery_inbox: Path, cust_sample_id: str) -> Path:
+@pytest.fixture
+def deliver_fastq_path(delivery_inbox: Path, cust_sample_id: str) -> Path:
     return Path(delivery_inbox, cust_sample_id, "dummy_run_R1_001.fastq.gz")
 
 
-@pytest.fixture(name="base_context")
-def fixture_base_context(
+@pytest.fixture
+def base_context(
     base_context: CGConfig, project_dir: Path, real_housekeeper_api: HousekeeperAPI
 ) -> CGConfig:
     base_context.housekeeper_api_ = real_housekeeper_api
@@ -40,11 +38,11 @@ def fixture_base_context(
     return base_context
 
 
-@pytest.fixture(name="mip_delivery_bundle")
-def fixture_mip_delivery_bundle(
+@pytest.fixture
+def mip_delivery_bundle(
     case_hk_bundle_no_files: dict,
-    sample_cram_files: List[Path],
-    sample_ids: List[str],
+    sample_cram_files: list[Path],
+    sample_ids: list[str],
     vcf_file: Path,
 ) -> dict:
     """Return a bundle that includes files used when delivering MIP analysis data"""
@@ -58,8 +56,8 @@ def fixture_mip_delivery_bundle(
     return case_hk_bundle_no_files
 
 
-@pytest.fixture(name="fastq_delivery_bundle")
-def fixture_fastq_delivery_bundle(
+@pytest.fixture
+def fastq_delivery_bundle(
     sample_hk_bundle_no_files: dict, fastq_file: Path, sample_id: str
 ) -> dict:
     """Return a sample bundle that includes a fastq file"""
@@ -70,8 +68,8 @@ def fixture_fastq_delivery_bundle(
     return sample_hk_bundle_no_files
 
 
-@pytest.fixture(name="mip_dna_housekeeper")
-def fixture_mip_dna_housekeeper(
+@pytest.fixture
+def mip_dna_housekeeper(
     real_housekeeper_api: HousekeeperAPI,
     mip_delivery_bundle: dict,
     fastq_delivery_bundle: dict,
@@ -88,8 +86,8 @@ def fixture_mip_dna_housekeeper(
     return real_housekeeper_api
 
 
-@pytest.fixture(name="populated_mip_context")
-def fixture_populated_mip_context(
+@pytest.fixture
+def populated_mip_context(
     base_context: CGConfig,
     analysis_store: Store,
     mip_dna_housekeeper: HousekeeperAPI,
@@ -101,8 +99,8 @@ def fixture_populated_mip_context(
     return base_context
 
 
-@pytest.fixture(name="context_with_missing_bundle")
-def fixture_context_with_missing_bundle(
+@pytest.fixture
+def context_with_missing_bundle(
     cg_context: CGConfig,
     analysis_store: Store,
     mip_dna_housekeeper: HousekeeperAPI,
