@@ -1,10 +1,10 @@
+from click.testing import CliRunner
+
 from cg.cli.get import get
 from cg.constants import EXIT_SUCCESS
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from click.testing import CliRunner
-
 from cg.store.models import Customer
+from cg.store.store import Store
 from tests.store_helpers import StoreHelpers
 
 
