@@ -1,11 +1,13 @@
 import logging
 from pathlib import Path
 
+from click.testing import CliRunner, Result
+
 import cg
 from cg.cli.base import base, init
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from click.testing import CliRunner, Result
+from cg.store.database import get_tables, initialize_database
+from cg.store.store import Store
 
 
 def test_cli_version(cli_runner: CliRunner):
@@ -27,7 +29,7 @@ def test_list_commands(cli_runner: CliRunner):
 
 def test_missing_command(cli_runner: CliRunner):
     # WHEN invoking a missing command
-    result = cli_runner.invoke(cg, ["i_dont_exist"])
+    result = cli_runner.invoke(base, ["i_dont_exist"])
     # THEN context should abort
     assert result.exit_code != 0
 
@@ -38,7 +40,8 @@ def test_cli_init(cli_runner: CliRunner, base_context: CGConfig, caplog, tmp_pat
     database = Path(tmp_path, "test_db.sqlite3")
     database_path = Path(database)
     database_uri = f"sqlite:///{database}"
-    base_context.status_db_ = Store(uri=database_uri)
+    initialize_database(database_uri)
+    base_context.status_db_ = Store()
 
     assert database_path.exists() is False
 
@@ -48,7 +51,7 @@ def test_cli_init(cli_runner: CliRunner, base_context: CGConfig, caplog, tmp_pat
     # THEN it should setup the database with some tables
     assert result.exit_code == 0
     assert database_path.exists()
-    assert len(Store(uri=database_uri).engine.table_names()) > 0
+    assert len(get_tables()) > 0
 
     # GIVEN the database already exists
     # WHEN calling the init function
