@@ -2,11 +2,12 @@
 
 import logging
 
+from click.testing import CliRunner
+
 from cg.apps.housekeeper.hk import HousekeeperAPI
 from cg.cli.upload.genotype import upload_genotypes as upload_genotypes_cmd
 from cg.models.cg_config import CGConfig
-from cg.store import Store
-from click.testing import CliRunner
+from cg.store.store import Store
 
 
 def test_upload_genotype(
