@@ -17,6 +17,7 @@ from cg.constants.sequencing import SequencingMethod
 from cg.constants.subject import PhenotypeStatus
 from cg.exc import CaseNotFoundError
 from cg.meta.observations.mip_dna_observations_api import MipDNAObservationsAPI
+from cg.meta.observations.raredisease_observations_api import RarediseaseObservationsAPI
 from cg.models.cg_config import CGConfig
 from cg.store.models import Case, CaseSample, Sample
 from cg.store.store import Store
@@ -107,3 +108,26 @@ def test_get_observations_api(cg_context: CGConfig, helpers: StoreHelpers):
     # THEN a MIP-DNA API should be returned
     assert observations_api
     assert isinstance(observations_api, MipDNAObservationsAPI)
+
+
+def test_get_observations_api_raredisease(cg_context: CGConfig, helpers: StoreHelpers):
+    """Test get observation API given a Loqusdb supported case."""
+    store: Store = cg_context.status_db
+
+    # GIVEN a Loqusdb supported case
+    case: Case = helpers.add_case(store, data_analysis=Workflow.RAREDISEASE)
+    sample: Sample = helpers.add_sample(store, application_type=SequencingMethod.WES)
+    case_sample: CaseSample = store.relate_sample(
+        case=case, sample=sample, status=PhenotypeStatus.UNKNOWN
+    )
+
+    store.session.add(case_sample)
+
+    # WHEN retrieving the observation API
+    observations_api: RarediseaseObservationsAPI = get_observations_api(
+        context=cg_context, case_id=case.internal_id, upload=True
+    )
+
+    # THEN a RAREDISEASE ObservationAPI should be returned
+    assert observations_api
+    assert isinstance(observations_api, RarediseaseObservationsAPI)
