@@ -4,10 +4,9 @@ import logging
 from pathlib import Path
 
 from _pytest.logging import LogCaptureFixture
-
-from cg.cli.workflow.balsamic.base import config_case
 from click.testing import CliRunner
 
+from cg.cli.workflow.balsamic.base import config_case
 from cg.models.cg_config import CGConfig
 
 EXIT_SUCCESS = 0
@@ -32,7 +31,7 @@ def test_with_missing_case(
     case_id = "soberelephant"
     assert not balsamic_context.status_db.get_case_by_internal_id(internal_id=case_id)
     # WHEN running
-    result = cli_runner.invoke(config_case, [case_id], obj=balsamic_context)
+    result = cli_runner.invoke(config_case, [case_id, "--dry-run"], obj=balsamic_context)
     # THEN command should NOT successfully call the command it creates
     assert result.exit_code != EXIT_SUCCESS
     # THEN ERROR log should be printed containing invalid case_id
@@ -55,21 +54,6 @@ def test_without_samples(
     assert "has no samples" in caplog.text
 
 
-def test_dry(cli_runner: CliRunner, balsamic_context: CGConfig, caplog: LogCaptureFixture):
-    """Test command with --dry option."""
-    caplog.set_level(logging.INFO)
-    # GIVEN a VALID case_id
-    case_id = "balsamic_case_wgs_paired"
-    # WHEN dry running with dry option specified
-    result = cli_runner.invoke(config_case, [case_id, "--dry-run"], obj=balsamic_context)
-    # THEN command should print the balsamic command string
-    assert result.exit_code == EXIT_SUCCESS
-    # THEN gry run, balsamic and case_id should be in log
-    assert "Dry run" in caplog.text
-    assert "balsamic" in caplog.text
-    assert case_id in caplog.text
-
-
 def test_genome_version(
     cli_runner: CliRunner, balsamic_context: CGConfig, caplog: LogCaptureFixture
 ):
@@ -81,9 +65,7 @@ def test_genome_version(
     option_value = "canfam3"
     # WHEN dry running with genome option specified
     result = cli_runner.invoke(
-        config_case,
-        [case_id, "--dry-run", option_key, option_value],
-        obj=balsamic_context,
+        config_case, [case_id, option_key, option_value, "--dry-run"], obj=balsamic_context
     )
     # THEN command should be generated successfully
     assert result.exit_code == EXIT_SUCCESS
@@ -106,9 +88,7 @@ def test_target_bed(
     option_value = balsamic_bed_2_path
     # WHEN dry running with PANEL BED option specified
     result = cli_runner.invoke(
-        config_case,
-        [case_id, "--dry-run", option_key, option_value],
-        obj=balsamic_context,
+        config_case, [case_id, option_key, option_value, "--dry-run"], obj=balsamic_context
     )
     # THEN command should be generated successfully
     assert result.exit_code == EXIT_SUCCESS
@@ -186,7 +166,7 @@ def test_pon_cnn(
     # WHEN dry running with PANEL BED and PON CNN options specified
     result = cli_runner.invoke(
         config_case,
-        [case_id, "--dry-run", panel_key, panel_value, pon_key, pon_value],
+        [case_id, panel_key, panel_value, pon_key, pon_value, "--dry-run"],
         obj=balsamic_context,
     )
     # THEN command should be generated successfully
@@ -241,7 +221,7 @@ def test_error_single_wgs_panel_arg(
     # WHEN dry running
     result = cli_runner.invoke(
         config_case,
-        [case_id, "--dry-run", "--panel-bed", panel_bed],
+        [case_id, "--panel-bed", panel_bed, "--dry-run"],
         obj=balsamic_context,
     )
     # THEN command is NOT generated successfully
@@ -250,10 +230,10 @@ def test_error_single_wgs_panel_arg(
     assert "Cannot set panel_bed for WGS sample" in caplog.text
 
 
-def test_error_normal_only(
+def test_single_normal_only(
     balsamic_context: CGConfig, cli_runner: CliRunner, caplog: LogCaptureFixture
 ):
-    """Test with case_id that has only one NORMAL sample."""
+    """Test with case_id that has only one normal sample."""
     caplog.set_level(logging.WARNING)
 
     # GIVEN case_id containing one normal sample
@@ -262,28 +242,6 @@ def test_error_normal_only(
     # WHEN dry running
     result = cli_runner.invoke(config_case, [case_id, "--dry-run"], obj=balsamic_context)
 
-    # THEN a start case error should be raised
-    assert result.exit_code != EXIT_SUCCESS
-    assert (
-        f"Case {case_id} only has a normal sample. Use the --force-normal flag to treat it as a tumor."
-        in caplog.text
-    )
-
-
-def test_normal_only_force_flag(
-    balsamic_context: CGConfig, cli_runner: CliRunner, caplog: LogCaptureFixture
-):
-    """Test with case_id that has only one NORMAL sample but the run is forced."""
-    caplog.set_level(logging.WARNING)
-
-    # GIVEN case_id containing one normal sample
-    case_id = "balsamic_case_tgs_single_error"
-
-    # WHEN dry running
-    result = cli_runner.invoke(
-        config_case, [case_id, "--dry-run", "--force-normal"], obj=balsamic_context
-    )
-
     # THEN command should be generated successfully
     assert result.exit_code == EXIT_SUCCESS
 
@@ -351,7 +309,7 @@ def test_error_mixed_panel_bed_resque(
     # WHEN dry running
     result = cli_runner.invoke(
         config_case,
-        [case_id, "--dry-run", "--panel-bed", panel_bed],
+        [case_id, "--panel-bed", panel_bed, "--dry-run"],
         obj=balsamic_context,
     )
     # THEN command is generated successfully
