@@ -1,7 +1,11 @@
 import logging
+from datetime import datetime
 from pathlib import Path
 
 import pytest
+from click.testing import CliRunner
+from pydantic import ValidationError
+
 from cg.apps.hermes.hermes_api import HermesApi
 from cg.apps.hermes.models import CGDeliverables
 from cg.apps.housekeeper.hk import HousekeeperAPI
@@ -9,11 +13,10 @@ from cg.cli.workflow.balsamic.base import store_housekeeper
 from cg.constants import EXIT_SUCCESS
 from cg.constants.constants import FileFormat
 from cg.io.controller import WriteStream
+from cg.meta.workflow.analysis import AnalysisAPI
 from cg.meta.workflow.balsamic import BalsamicAnalysisAPI
 from cg.models.cg_config import CGConfig
 from cg.utils import Process
-from click.testing import CliRunner
-from pydantic import ValidationError
 
 
 def test_without_options(cli_runner: CliRunner, balsamic_context: CGConfig):
@@ -104,7 +107,7 @@ def test_case_with_malformed_deliverables_file(
     # GIVEN that the output is malformed
     with pytest.raises(ValidationError):
         analysis_api.hermes_api.convert_deliverables(
-            deliverables_file=Path("a_file"), pipeline="balsamic"
+            deliverables_file=Path("a_file"), workflow="balsamic"
         )
 
         # GIVEN case-id
