@@ -2,7 +2,10 @@
 
 import pytest
 
-from cg.constants.pacbio import PacBioDirsAndFiles
+
+@pytest.fixture
+def pac_bio_smrt_cell_name() -> str:
+    return "1_A01"
 
 
 @pytest.fixture
@@ -11,6 +14,12 @@ def pac_bio_test_run_name() -> str:
     return "r84202_20240522_133539"
 
 
+@pytest.fixture
+def pac_bio_sequencing_run_name(pac_bio_test_run_name: str, pac_bio_smrt_cell_name: str) -> str:
+    """Return the name of a PacBio SMRT cell."""
+    return f"{pac_bio_test_run_name}/{pac_bio_smrt_cell_name})"
+
+
 @pytest.fixture
 def pac_bio_1_a01_cell_full_name() -> str:
     """Return the full name of a PacBio SMRT cell."""
@@ -18,6 +27,10 @@ def pac_bio_1_a01_cell_full_name() -> str:
 
 
 @pytest.fixture
-def ccs_report_1_a01_name(pac_bio_1_a01_cell_full_name: str) -> str:
-    """Return the name of a ccs report file."""
-    return f"{pac_bio_1_a01_cell_full_name}.{PacBioDirsAndFiles.CCS_REPORT_SUFFIX}"
+def smrt_cell_internal_id() -> str:
+    return "EA094834"
+
+
+@pytest.fixture
+def pac_bio_sample_internal_id() -> str:
+    return "1247014000119"
