@@ -3,21 +3,26 @@
 import logging
 from datetime import datetime
 from pathlib import Path
-from typing import Dict, Generator, List
+from typing import Generator
 
 import pytest
 from housekeeper.store.models import Version
 
-from cg.constants import DataDelivery, Pipeline
+from cg.constants import DataDelivery, Workflow
 from cg.constants.constants import FileFormat, PrepCategory
+from cg.constants.housekeeper_tags import HK_DELIVERY_REPORT_TAG
+from cg.constants.pedigree import Pedigree
+from cg.constants.scout import UploadTrack
 from cg.constants.sequencing import SequencingMethod
+from cg.constants.subject import PhenotypeStatus
 from cg.io.controller import ReadFile
 from cg.meta.upload.scout.balsamic_config_builder import BalsamicConfigBuilder
 from cg.meta.upload.scout.mip_config_builder import MipConfigBuilder
 from cg.meta.upload.scout.uploadscoutapi import UploadScoutAPI
+from cg.models.cg_config import CGConfig
 from cg.models.scout.scout_load_config import MipLoadConfig
-from cg.store import Store
-from cg.store.models import Analysis, Family, Sample
+from cg.store.models import Analysis, Case, Sample
+from cg.store.store import Store
 
 # Mocks
 from tests.mocks.hk_mock import MockHousekeeperAPI
@@ -30,68 +35,88 @@ from tests.store_helpers import StoreHelpers
 LOG = logging.getLogger(__name__)
 
 
-@pytest.fixture(name="rna_case_id")
-def fixture_rna_case_id() -> str:
+@pytest.fixture
+def rna_case_id() -> str:
     """Return a rna case id."""
     return "affirmativecat"
 
 
-@pytest.fixture(name="dna_case_id")
-def fixture_dna_case_id(case_id: str) -> str:
+@pytest.fixture
+def dna_case_id(case_id: str) -> str:
     """Return a DNA case id."""
     return case_id
 
 
-@pytest.fixture(name="rna_sample_son_id")
-def fixture_rna_sample_son_id() -> str:
+@pytest.fixture
+def rna_sample_son_id() -> str:
     """Return a son RNA sample id."""
     return "rna_son"
 
 
-@pytest.fixture(name="rna_sample_daughter_id")
-def fixture_rna_sample_daughter_id() -> str:
+@pytest.fixture
+def rna_sample_daughter_id() -> str:
     """Return a daughter RNA sample id."""
     return "rna_daughter"
 
 
-@pytest.fixture(name="rna_sample_mother_id")
-def fixture_rna_sample_mother_id() -> str:
+@pytest.fixture
+def rna_sample_mother_id() -> str:
     """Return a mother RNA sample id."""
     return "rna_mother"
 
 
-@pytest.fixture(name="rna_sample_father_id")
-def fixture_rna_sample_father_id() -> str:
+@pytest.fixture
+def rna_sample_father_id() -> str:
     """Return a father RNA sample id."""
     return "rna_father"
 
 
-@pytest.fixture(name="dna_sample_son_id")
-def fixture_dna_sample_son_id() -> str:
+@pytest.fixture
+def dna_sample_son_id() -> str:
     """Return a son DNA sample id."""
     return "dna_son"
 
 
-@pytest.fixture(name="another_sample_id")
-def fixture_another_sample_id() -> str:
-    """Return another sample id."""
-    return "another_sample_id"
+@pytest.fixture
+def dna_sample_daughter_id() -> str:
+    """Return a daughter DNA sample id."""
+    return "dna_daughter"
 
 
-@pytest.fixture(name="another_rna_sample_id")
-def fixture_another_rna_sample_id() -> str:
+@pytest.fixture
+def dna_sample_mother_id() -> str:
+    """Return a mother DNA sample id."""
+    return "dna_mother"
+
+
+@pytest.fixture
+def dna_sample_father_id() -> str:
+    """Return a father DNA sample id."""
+    return "dna_father"
+
+
+@pytest.fixture
+def another_rna_sample_id() -> str:
     """Return another RNA sample id."""
     return "another_rna_sample_id"
 
 
-@pytest.fixture(name="rna_store")
-def fixture_rna_store(
+@pytest.fixture
+def rna_store(
     base_store: Store,
     helpers: StoreHelpers,
     rna_case_id: str,
     dna_case_id: str,
+    rna_sample_son_id: str,
+    rna_sample_daughter_id: str,
+    rna_sample_father_id: str,
+    rna_sample_mother_id: str,
+    dna_sample_son_id: str,
+    dna_sample_daughter_id: str,
+    dna_sample_father_id: str,
+    dna_sample_mother_id: str,
 ) -> Store:
-    """Populate store with a RNA case that is connected to a DNA case via sample.subject_id."""
+    """Populate store with an RNA case that is connected to a DNA case via subject ID."""
 
     store: Store = base_store
 
@@ -100,34 +125,34 @@ def fixture_rna_store(
         store=store,
         case_name="rna_case",
         customer=helpers.ensure_customer(store=store),
-        data_analysis=Pipeline.MIP_RNA,
+        data_analysis=Workflow.MIP_RNA,
         data_delivery=DataDelivery.SCOUT,
     )
     rna_case.internal_id = rna_case_id
 
     rna_sample_son = helpers.add_sample(
         store=store,
-        name="rna_son",
-        subject_id="son",
         application_type=SequencingMethod.WTS,
+        name=rna_sample_son_id,
+        subject_id="son",
     )
     rna_sample_daughter = helpers.add_sample(
         store=store,
-        name="rna_daughter",
-        subject_id="daughter",
         application_type=SequencingMethod.WTS,
+        name=rna_sample_daughter_id,
+        subject_id="daughter",
     )
     rna_sample_mother = helpers.add_sample(
         store=store,
-        name="rna_mother",
-        subject_id="mother",
         application_type=SequencingMethod.WTS,
+        name=rna_sample_mother_id,
+        subject_id=Pedigree.MOTHER,
     )
     rna_sample_father = helpers.add_sample(
         store=store,
-        name="rna_father",
-        subject_id="father",
         application_type=SequencingMethod.WTS,
+        name=rna_sample_father_id,
+        subject_id=Pedigree.FATHER,
     )
     helpers.add_relationship(
         store=store,
@@ -135,7 +160,7 @@ def fixture_rna_store(
         case=rna_case,
         mother=rna_sample_mother,
         father=rna_sample_father,
-        status="affected",
+        status=PhenotypeStatus.AFFECTED,
     )
     helpers.add_relationship(
         store=store,
@@ -143,13 +168,13 @@ def fixture_rna_store(
         case=rna_case,
         mother=rna_sample_mother,
         father=rna_sample_father,
-        status="unaffected",
+        status=PhenotypeStatus.UNAFFECTED,
     )
     helpers.add_relationship(
-        store=store, sample=rna_sample_mother, case=rna_case, status="unaffected"
+        store=store, sample=rna_sample_mother, case=rna_case, status=PhenotypeStatus.UNAFFECTED
     )
     helpers.add_relationship(
-        store=store, sample=rna_sample_father, case=rna_case, status="affected"
+        store=store, sample=rna_sample_father, case=rna_case, status=PhenotypeStatus.AFFECTED
     )
 
     for link in rna_case.links:
@@ -160,38 +185,38 @@ def fixture_rna_store(
         store=store,
         case_name="dna_case",
         customer=helpers.ensure_customer(store=store),
-        data_analysis=Pipeline.MIP_DNA,
+        data_analysis=Workflow.MIP_DNA,
         data_delivery=DataDelivery.SCOUT,
     )
     dna_case.internal_id = dna_case_id
 
     dna_sample_son = helpers.add_sample(
         store=store,
-        name="dna_son",
-        subject_id="son",
         application_tag=SequencingMethod.WGS,
         application_type=SequencingMethod.WGS,
+        name=dna_sample_son_id,
+        subject_id="son",
     )
     dna_sample_daughter = helpers.add_sample(
         store=store,
-        name="dna_daughter",
-        subject_id="daughter",
         application_tag=SequencingMethod.WGS,
         application_type=SequencingMethod.WGS,
+        name=dna_sample_daughter_id,
+        subject_id="daughter",
     )
     dna_sample_mother = helpers.add_sample(
         store=store,
-        name="dna_mother",
-        subject_id="mother",
         application_tag=SequencingMethod.WGS,
         application_type=SequencingMethod.WGS,
+        name=dna_sample_mother_id,
+        subject_id=Pedigree.MOTHER,
     )
     dna_sample_father = helpers.add_sample(
         store=store,
-        name="dna_father",
-        subject_id="father",
         application_tag=SequencingMethod.WGS,
         application_type=SequencingMethod.WGS,
+        name=dna_sample_father_id,
+        subject_id=Pedigree.FATHER,
     )
     helpers.add_relationship(
         store=store,
@@ -199,7 +224,7 @@ def fixture_rna_store(
         case=dna_case,
         mother=dna_sample_mother,
         father=dna_sample_father,
-        status="affected",
+        status=PhenotypeStatus.AFFECTED,
     )
     helpers.add_relationship(
         store=store,
@@ -207,24 +232,26 @@ def fixture_rna_store(
         case=dna_case,
         mother=dna_sample_mother,
         father=dna_sample_father,
-        status="unaffected",
+        status=PhenotypeStatus.UNAFFECTED,
     )
     helpers.add_relationship(
-        store=store, sample=dna_sample_mother, case=dna_case, status="unaffected"
+        store=store, sample=dna_sample_mother, case=dna_case, status=PhenotypeStatus.UNAFFECTED
     )
     helpers.add_relationship(
-        store=store, sample=dna_sample_father, case=dna_case, status="affected"
+        store=store, sample=dna_sample_father, case=dna_case, status=PhenotypeStatus.AFFECTED
     )
 
     for link in dna_case.links:
         link.sample.internal_id = link.sample.name
 
+    helpers.add_analysis(store=store, case=dna_case, uploaded_at=datetime.now())
+
     store.session.commit()
     return store
 
 
 @pytest.fixture(name="lims_family")
-def fixture_lims_family(fixtures_dir) -> dict:
+def lims_family(fixtures_dir) -> dict:
     """Returns a LIMS-like case of samples."""
     return ReadFile.get_content_from_file(
         file_format=FileFormat.JSON, file_path=Path(fixtures_dir, "report", "lims_family.json")
@@ -232,13 +259,13 @@ def fixture_lims_family(fixtures_dir) -> dict:
 
 
 @pytest.fixture(name="lims_samples")
-def fixture_lims_samples(lims_family: dict) -> List[dict]:
+def lims_samples(lims_family: dict) -> list[dict]:
     """Returns the samples of a LIMS case."""
     return lims_family["samples"]
 
 
-@pytest.fixture(scope="function", name="mip_dna_analysis_hk_bundle_data")
-def fixture_mip_dna_analysis_hk_bundle_data(
+@pytest.fixture(scope="function")
+def mip_dna_analysis_hk_bundle_data(
     case_id: str,
     timestamp: datetime,
     mip_dna_analysis_dir: Path,
@@ -247,6 +274,7 @@ def fixture_mip_dna_analysis_hk_bundle_data(
     sv_vcf_file: str,
     snv_research_vcf_file: str,
     sv_research_vcf_file: str,
+    delivery_report_html: Path,
 ) -> dict:
     """Return MIP DNA bundle data for Housekeeper."""
     return {
@@ -313,8 +341,8 @@ def fixture_mip_dna_analysis_hk_bundle_data(
     }
 
 
-@pytest.fixture(scope="function", name="mip_rna_analysis_hk_bundle_data")
-def fixture_mip_rna_analysis_hk_bundle_data(
+@pytest.fixture(scope="function")
+def mip_rna_analysis_hk_bundle_data(
     rna_case_id: str,
     timestamp: datetime,
     mip_dna_analysis_dir: Path,
@@ -325,7 +353,12 @@ def fixture_mip_rna_analysis_hk_bundle_data(
 ) -> dict:
     """Return MIP RNA bundle data for Housekeeper."""
 
-    files: List[dict] = [
+    files: list[dict] = [
+        {
+            "path": Path(mip_dna_analysis_dir, f"{rna_case_id}.cram").as_posix(),
+            "archive": False,
+            "tags": ["cram", rna_case_id],
+        },
         {
             "path": Path(mip_dna_analysis_dir, f"{rna_case_id}_report.selected.pdf").as_posix(),
             "archive": False,
@@ -370,8 +403,8 @@ def fixture_mip_rna_analysis_hk_bundle_data(
     }
 
 
-@pytest.fixture(scope="function", name="balsamic_analysis_hk_bundle_data")
-def fixture_balsamic_analysis_hk_bundle_data(
+@pytest.fixture(scope="function")
+def balsamic_analysis_hk_bundle_data(
     case_id: str,
     timestamp: datetime,
     balsamic_wgs_analysis_dir: Path,
@@ -419,9 +452,9 @@ def fixture_balsamic_analysis_hk_bundle_data(
     }
 
 
-@pytest.fixture(scope="function", name="rnafusion_analysis_hk_bundle_data")
-def fixture_rnafusion_analysis_hk_bundle_data(
-    case_id: str, timestamp: datetime, rnafusion_analysis_dir: Path
+@pytest.fixture(scope="function")
+def rnafusion_analysis_hk_bundle_data(
+    case_id: str, timestamp: datetime, rnafusion_analysis_dir: Path, delivery_report_html: Path
 ) -> dict:
     """Get some bundle data for housekeeper."""
     return {
@@ -439,28 +472,33 @@ def fixture_rnafusion_analysis_hk_bundle_data(
                 "archive": False,
                 "tags": ["fusionreport", "research"],
             },
+            {
+                "path": delivery_report_html.as_posix(),
+                "archive": False,
+                "tags": [HK_DELIVERY_REPORT_TAG],
+            },
         ],
     }
 
 
-@pytest.fixture(name="balsamic_analysis_hk_version")
-def fixture_balsamic_analysis_hk_version(
+@pytest.fixture
+def balsamic_analysis_hk_version(
     housekeeper_api: MockHousekeeperAPI, balsamic_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return Housekeeper version for a Balsamic bundle."""
     return helpers.ensure_hk_version(housekeeper_api, balsamic_analysis_hk_bundle_data)
 
 
-@pytest.fixture(name="mip_dna_analysis_hk_version")
-def fixture_mip_dna_analysis_hk_version(
+@pytest.fixture
+def mip_dna_analysis_hk_version(
     housekeeper_api: MockHousekeeperAPI, mip_dna_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return Housekeeper version for a MIP DNA bundle."""
     return helpers.ensure_hk_version(housekeeper_api, mip_dna_analysis_hk_bundle_data)
 
 
-@pytest.fixture(name="mip_dna_analysis_hk_api")
-def fixture_mip_dna_analysis_hk_api(
+@pytest.fixture
+def mip_dna_analysis_hk_api(
     housekeeper_api: MockHousekeeperAPI, mip_dna_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return a Housekeeper API populated with MIP DNA analysis files."""
@@ -468,8 +506,8 @@ def fixture_mip_dna_analysis_hk_api(
     return housekeeper_api
 
 
-@pytest.fixture(name="mip_rna_analysis_hk_api")
-def fixture_mip_rna_analysis_hk_api(
+@pytest.fixture
+def mip_rna_analysis_hk_api(
     housekeeper_api: MockHousekeeperAPI, mip_rna_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return a Housekeeper API populated with MIP RNA analysis files."""
@@ -477,8 +515,8 @@ def fixture_mip_rna_analysis_hk_api(
     return housekeeper_api
 
 
-@pytest.fixture(name="balsamic_analysis_hk_api")
-def fixture_balsamic_analysis_hk_api(
+@pytest.fixture
+def balsamic_analysis_hk_api(
     housekeeper_api: MockHousekeeperAPI, balsamic_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return a Housekeeper API populated with Balsamic analysis files."""
@@ -486,8 +524,8 @@ def fixture_balsamic_analysis_hk_api(
     return housekeeper_api
 
 
-@pytest.fixture(name="rnafusion_analysis_hk_api")
-def fixture_rnafusion_analysis_hk_api(
+@pytest.fixture
+def rnafusion_analysis_hk_api(
     housekeeper_api: MockHousekeeperAPI, rnafusion_analysis_hk_bundle_data: dict, helpers
 ) -> MockHousekeeperAPI:
     """Return a housekeeper api populated with some rnafusion analysis files"""
@@ -495,19 +533,19 @@ def fixture_rnafusion_analysis_hk_api(
     return housekeeper_api
 
 
-@pytest.fixture(name="mip_dna_analysis")
-def fixture_mip_dna_analysis(
+@pytest.fixture
+def mip_dna_analysis(
     analysis_store_trio: Store, case_id: str, timestamp: datetime, helpers: StoreHelpers
 ) -> Analysis:
     """Return a MIP DNA analysis object."""
     helpers.add_synopsis_to_case(store=analysis_store_trio, case_id=case_id)
-    case: Family = analysis_store_trio.get_case_by_internal_id(internal_id=case_id)
+    case: Case = analysis_store_trio.get_case_by_internal_id(internal_id=case_id)
     analysis: Analysis = helpers.add_analysis(
         store=analysis_store_trio,
         case=case,
         started_at=timestamp,
-        pipeline=Pipeline.MIP_DNA,
         completed_at=timestamp,
+        workflow=Workflow.MIP_DNA,
     )
     for link in case.links:
         helpers.add_phenotype_groups_to_sample(
@@ -522,46 +560,46 @@ def fixture_mip_dna_analysis(
     return analysis
 
 
-@pytest.fixture(name="balsamic_analysis_obj")
-def fixture_balsamic_analysis_obj(analysis_obj: Analysis) -> Analysis:
+@pytest.fixture
+def balsamic_analysis_obj(analysis_obj: Analysis) -> Analysis:
     """Return a Balsamic analysis object."""
-    analysis_obj.pipeline = Pipeline.BALSAMIC
-    for link_object in analysis_obj.family.links:
+    analysis_obj.workflow = Workflow.BALSAMIC
+    for link_object in analysis_obj.case.links:
         link_object.sample.application_version.application.prep_category = (
             PrepCategory.WHOLE_EXOME_SEQUENCING
         )
-        link_object.family.data_analysis = Pipeline.BALSAMIC
+        link_object.case.data_analysis = Workflow.BALSAMIC
     return analysis_obj
 
 
-@pytest.fixture(name="balsamic_umi_analysis_obj")
-def fixture_balsamic_umi_analysis_obj(analysis_obj: Analysis) -> Analysis:
+@pytest.fixture
+def balsamic_umi_analysis_obj(analysis_obj: Analysis) -> Analysis:
     """Return a Balsamic UMI analysis object."""
-    analysis_obj.pipeline = Pipeline.BALSAMIC_UMI
-    for link_object in analysis_obj.family.links:
+    analysis_obj.workflow = Workflow.BALSAMIC_UMI
+    for link_object in analysis_obj.case.links:
         link_object.sample.application_version.application.prep_category = (
             PrepCategory.WHOLE_EXOME_SEQUENCING
         )
-        link_object.family.data_analysis = Pipeline.BALSAMIC_UMI
+        link_object.case.data_analysis = Workflow.BALSAMIC_UMI
 
     return analysis_obj
 
 
-@pytest.fixture(name="rnafusion_analysis_obj")
-def fixture_rnafusion_analysis_obj(analysis_obj: Analysis) -> Analysis:
+@pytest.fixture
+def rnafusion_analysis_obj(analysis_obj: Analysis) -> Analysis:
     """Return a RNAfusion analysis object."""
-    analysis_obj.pipeline = Pipeline.RNAFUSION
-    for link_object in analysis_obj.family.links:
+    analysis_obj.workflow = Workflow.RNAFUSION
+    for link_object in analysis_obj.case.links:
         link_object.sample.application_version.application.prep_category = (
             PrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING
         )
-        link_object.family.data_analysis = Pipeline.RNAFUSION
-        link_object.family.panels = None
+        link_object.case.data_analysis = Workflow.RNAFUSION
+        link_object.case.panels = None
     return analysis_obj
 
 
-@pytest.fixture(name="mip_config_builder")
-def fixture_mip_config_builder(
+@pytest.fixture
+def mip_config_builder(
     mip_dna_analysis_hk_version: Version,
     mip_dna_analysis: Analysis,
     lims_api: MockLimsAPI,
@@ -578,8 +616,8 @@ def fixture_mip_config_builder(
     )
 
 
-@pytest.fixture(name="balsamic_config_builder")
-def fixture_balsamic_config_builder(
+@pytest.fixture
+def balsamic_config_builder(
     balsamic_analysis_hk_version: Version,
     balsamic_analysis_obj: Analysis,
     lims_api: MockLimsAPI,
@@ -592,41 +630,47 @@ def fixture_balsamic_config_builder(
     )
 
 
-@pytest.fixture(name="mip_load_config")
-def fixture_mip_load_config(
-    mip_dna_analysis_dir: Path, case_id: str, customer_id: str, snv_vcf_file: str
+@pytest.fixture
+def mip_load_config(
+    mip_dna_analysis_dir: Path,
+    case_id: str,
+    customer_id: str,
+    snv_vcf_file: str,
+    delivery_report_html: Path,
 ) -> MipLoadConfig:
     """Return a valid MIP load_config."""
     return MipLoadConfig(
         owner=customer_id,
         family=case_id,
         vcf_snv=Path(mip_dna_analysis_dir, snv_vcf_file).as_posix(),
-        track="rare",
+        track=UploadTrack.RARE_DISEASE.value,
+        delivery_report=delivery_report_html.as_posix(),
     )
 
 
-@pytest.fixture(name="lims_api")
-def fixture_lims_api(lims_samples: List[dict]) -> MockLimsAPI:
+@pytest.fixture
+def lims_api(lims_samples: list[dict]) -> MockLimsAPI:
     """Return a LIMS API."""
     return MockLimsAPI(samples=lims_samples)
 
 
-@pytest.fixture(name="mip_analysis_api")
-def fixture_mip_analysis_api() -> MockMipAnalysis:
+@pytest.fixture
+def mip_analysis_api(cg_context: CGConfig) -> MockMipAnalysis:
     """Return a MIP analysis API."""
-    return MockMipAnalysis()
+    return MockMipAnalysis(config=cg_context, workflow=Workflow.MIP_DNA)
 
 
-@pytest.fixture(name="upload_scout_api")
-def fixture_upload_scout_api(
+@pytest.fixture
+def upload_scout_api(
+    cg_context: CGConfig,
     scout_api: MockScoutAPI,
     madeline_api: MockMadelineAPI,
-    lims_samples: List[dict],
+    lims_samples: list[dict],
     housekeeper_api: MockHousekeeperAPI,
     store: Store,
 ) -> UploadScoutAPI:
     """Return upload Scout API."""
-    analysis_mock = MockMipAnalysis()
+    analysis_mock = MockMipAnalysis(config=cg_context, workflow=Workflow.MIP_DNA)
     lims_api = MockLimsAPI(samples=lims_samples)
 
     return UploadScoutAPI(
@@ -639,16 +683,17 @@ def fixture_upload_scout_api(
     )
 
 
-@pytest.fixture(name="upload_mip_analysis_scout_api")
-def fixture_upload_mip_analysis_scout_api(
+@pytest.fixture
+def upload_mip_analysis_scout_api(
+    cg_context: CGConfig,
     scout_api: MockScoutAPI,
     madeline_api: MockMadelineAPI,
-    lims_samples: List[dict],
+    lims_samples: list[dict],
     mip_dna_analysis_hk_api: MockHousekeeperAPI,
     store: Store,
 ) -> Generator[UploadScoutAPI, None, None]:
     """Return MIP upload Scout API."""
-    analysis_mock = MockMipAnalysis()
+    analysis_mock = MockMipAnalysis(config=cg_context, workflow=Workflow.MIP_DNA)
     lims_api = MockLimsAPI(samples=lims_samples)
 
     yield UploadScoutAPI(
@@ -661,16 +706,17 @@ def fixture_upload_mip_analysis_scout_api(
     )
 
 
-@pytest.fixture(name="upload_balsamic_analysis_scout_api")
-def fixture_upload_balsamic_analysis_scout_api(
+@pytest.fixture
+def upload_balsamic_analysis_scout_api(
+    cg_context: CGConfig,
     scout_api: MockScoutAPI,
     madeline_api: MockMadelineAPI,
-    lims_samples: List[dict],
+    lims_samples: list[dict],
     balsamic_analysis_hk_api: MockHousekeeperAPI,
     store: Store,
 ) -> Generator[UploadScoutAPI, None, None]:
     """Return Balsamic upload Scout API."""
-    analysis_mock = MockMipAnalysis()
+    analysis_mock = MockMipAnalysis(config=cg_context, workflow=Workflow.MIP_DNA)
     lims_api = MockLimsAPI(samples=lims_samples)
 
     yield UploadScoutAPI(
@@ -683,17 +729,17 @@ def fixture_upload_balsamic_analysis_scout_api(
     )
 
 
-@pytest.fixture(name="rna_dna_sample_case_map")
-def fixture_rna_dna_sample_case_map(
+@pytest.fixture
+def rna_dna_sample_case_map(
     rna_sample_son_id: str,
     rna_store: Store,
     upload_scout_api: UploadScoutAPI,
-) -> Dict[str, List[str]]:
+) -> dict[str, list[str]]:
     """Return a valid RNA-DNA case map."""
     rna_sample: Sample = rna_store.get_sample_by_internal_id(internal_id=rna_sample_son_id)
 
     # WHEN adding the RNA sample rna_dna_case_map
-    rna_dna_sample_case_map: Dict[str, Dict[str, List[str]]] = {}
+    rna_dna_sample_case_map: dict[str, dict[str, list[str]]] = {}
     upload_scout_api._map_dna_samples_related_to_rna_sample(
         rna_sample=rna_sample, rna_dna_sample_case_map=rna_dna_sample_case_map
     )
@@ -701,16 +747,17 @@ def fixture_rna_dna_sample_case_map(
     return rna_dna_sample_case_map
 
 
-@pytest.fixture(name="upload_rnafusion_analysis_scout_api")
-def fixture_upload_rnafusion_analysis_scout_api(
+@pytest.fixture
+def upload_rnafusion_analysis_scout_api(
+    cg_context: CGConfig,
     scout_api: MockScoutAPI,
     madeline_api: MockMadelineAPI,
-    lims_samples: List[dict],
+    lims_samples: list[dict],
     rnafusion_analysis_hk_api: MockHousekeeperAPI,
     store: Store,
 ) -> UploadScoutAPI:
     """Fixture for upload_scout_api."""
-    analysis_mock = MockMipAnalysis()
+    analysis_mock = MockMipAnalysis(config=cg_context, workflow=Workflow.MIP_DNA)
     lims_api = MockLimsAPI(samples=lims_samples)
 
     _api = UploadScoutAPI(
