@@ -3,9 +3,8 @@
 import copy
 import logging
 from subprocess import CalledProcessError
-from typing import List
 
-from cg.constants import RETURN_SUCCESS
+from cg.constants import EXIT_SUCCESS
 from cg.utils.commands import Process
 
 LOG = logging.getLogger(__name__)
@@ -33,7 +32,7 @@ class ProcessMock(Process):
         )
         self.config_parameter = config_parameter
         LOG.debug("Initialising Process with binary: %s", self.binary)
-        self.base_call: List = []
+        self.base_call = []
         if self.binary:
             self.base_call.append(self.binary)
             if self.environment:
@@ -42,7 +41,7 @@ class ProcessMock(Process):
             if self.config:
                 self.base_call.extend([self.config_parameter, self.config])
             LOG.debug("Use base call %s", self.base_call)
-        self._exit_code: int = RETURN_SUCCESS
+        self._exit_code: int = EXIT_SUCCESS
         if error:
             self._exit_code = 1
 
@@ -63,14 +62,14 @@ class ProcessMock(Process):
 
         LOG.info("Running command %s", " ".join(command))
         if dry_run:
-            return RETURN_SUCCESS
+            return EXIT_SUCCESS
 
-        if self._exit_code != RETURN_SUCCESS:
+        if self._exit_code != EXIT_SUCCESS:
             LOG.critical("Call %s exit with a non zero exit code", command)
             LOG.critical(self.stderr)
             raise CalledProcessError(self._exit_code, command)
 
-        return RETURN_SUCCESS
+        return EXIT_SUCCESS
 
     def set_stdout(self, text: str):
         """Mock the stdout"""
