@@ -1,15 +1,14 @@
 """Mock the scout api"""
 
 import logging
-from pathlib import Path
-from pydantic import BaseModel, validator
-from typing import List
+from mock import Mock
+
+from pydantic.v1 import BaseModel, validator
 from typing_extensions import Literal
 
 from cg.apps.scout.scoutapi import ScoutAPI
 from tests.mocks.process_mock import ProcessMock
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -60,6 +59,7 @@ class MockScoutAPI(ScoutAPI):
         self._upload_report_success = True
         self._alignment_file_updated = 0
         self.process = ProcessMock(binary="scout", error=False)
+        self.slurm_upload_service = Mock()
 
     # Mock specific functions
 
@@ -81,7 +81,7 @@ class MockScoutAPI(ScoutAPI):
         """Load analysis of a new case into Scout."""
         LOG.debug("Case loaded successfully to Scout")
 
-    def export_panels(self, panels: List[str], versions=None):
+    def export_panels(self, panels: list[str], versions=None):
         """Pass through to export of a list of gene panels."""
         return self._panels
 
