@@ -19,6 +19,7 @@ from cg.services.illumina.data_transfer.models import (
     IlluminaSampleSequencingMetricsDTO,
     IlluminaSequencingRunDTO,
 )
+from cg.store.exc import EntryNotFoundError
 from cg.store.models import (
     Analysis,
     Application,
@@ -218,6 +219,8 @@ class StoreHelpers:
         prep_category: str = "wgs",
         description: str = None,
         is_archived: bool = False,
+        target_reads: int = None,
+        percent_reads_guaranteed: int = 75,
         is_accredited: bool = False,
         is_external: bool = False,
         min_sequencing_depth: int = 30,
@@ -236,7 +239,8 @@ class StoreHelpers:
             description=description,
             is_archived=is_archived,
             percent_kth=80,
-            percent_reads_guaranteed=75,
+            target_reads=target_reads,
+            percent_reads_guaranteed=percent_reads_guaranteed,
             is_accredited=is_accredited,
             limitations="A limitation",
             is_external=is_external,
@@ -380,23 +384,22 @@ class StoreHelpers:
         **kwargs,
     ) -> Sample:
         """Utility function to add a sample to use in tests."""
-        customer_id = customer_id or "cust000"
-        customer = StoreHelpers.ensure_customer(store, customer_id=customer_id)
-        application_version = StoreHelpers.ensure_application_version(
+        customer_id: str = customer_id or "cust000"
+        customer: Customer = StoreHelpers.ensure_customer(store, customer_id=customer_id)
+        application_version: ApplicationVersion = StoreHelpers.ensure_application_version(
             store=store,
             application_tag=application_tag,
             prep_category=application_type,
             is_external=is_external,
             is_rna=is_rna,
         )
-        application_version_id = application_version.id
+        application_version_id: int = application_version.id
 
         if internal_id:
-            existing_sample: Sample = store.get_sample_by_internal_id(internal_id=internal_id)
-            if existing_sample:
+            if existing_sample := store.get_sample_by_internal_id(internal_id=internal_id):
                 return existing_sample
 
-        sample = store.add_sample(
+        sample: Sample = store.add_sample(
             name=name,
             sex=sex,
             control=control,
@@ -693,14 +696,14 @@ class StoreHelpers:
         model: str = "10B",
     ) -> IlluminaFlowCell:
         """Return an Illumina flow cell if exists, otherwise add it to the store and return it."""
-        flow_cell: IlluminaFlowCell | None = store.get_illumina_flow_cell_by_internal_id(
-            internal_id=flow_cell_id
-        )
-        if flow_cell:
-            return flow_cell
-        flow_cell: IlluminaFlowCell = cls.add_illumina_flow_cell(
-            store=store, flow_cell_id=flow_cell_id, model=model
-        )
+        try:
+            flow_cell: IlluminaFlowCell | None = store.get_illumina_flow_cell_by_internal_id(
+                internal_id=flow_cell_id
+            )
+        except EntryNotFoundError:
+            flow_cell: IlluminaFlowCell = cls.add_illumina_flow_cell(
+                store=store, flow_cell_id=flow_cell_id, model=model
+            )
         return flow_cell
 
     @staticmethod
@@ -757,22 +760,22 @@ class StoreHelpers:
         """
         Return an Illumina sequencing run if exists, otherwise add it to the store and return it.
         """
-        illumina_run: IlluminaSequencingRun | None = (
-            store.get_illumina_sequencing_run_by_device_internal_id(
-                device_internal_id=flow_cell.internal_id
+        try:
+            illumina_run: IlluminaSequencingRun | None = (
+                store.get_illumina_sequencing_run_by_device_internal_id(
+                    device_internal_id=flow_cell.internal_id
+                )
+            )
+        except EntryNotFoundError:
+            illumina_run: IlluminaSequencingRun = cls.add_illumina_sequencing_run(
+                store=store,
+                flow_cell=flow_cell,
+                sequencer_type=sequencer_type,
+                sequencer_name=sequencer_name,
+                data_availability=data_availability,
+                archived_at=archived_at,
+                has_backup=has_backup,
             )
-        )
-        if illumina_run:
-            return illumina_run
-        illumina_run: IlluminaSequencingRun = cls.add_illumina_sequencing_run(
-            store=store,
-            flow_cell=flow_cell,
-            sequencer_type=sequencer_type,
-            sequencer_name=sequencer_name,
-            data_availability=data_availability,
-            archived_at=archived_at,
-            has_backup=has_backup,
-        )
         return illumina_run
 
     @staticmethod
