@@ -4,22 +4,7 @@ import math
 
 import pytest
 
-from cg.utils.calculations import (
-    divide_by_thousand_with_one_decimal,
-    fraction_to_percent,
-    multiply_by_million,
-)
-
-
-def test_divide_by_thousand_with_one_decimal():
-    # GIVEN a number
-    number: float = 1_234.00
-
-    # WHEN dividing by a thousand
-    divided: float = divide_by_thousand_with_one_decimal(number)
-
-    # THEN the number should be divided by a thousand and only one decimal should be kept
-    assert math.isclose(divided, 1.2, abs_tol=1e-9)
+from cg.utils.calculations import fraction_to_percent, multiply_by_million
 
 
 @pytest.mark.parametrize(
